# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/data_contracts/v1/data_contracts_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9strmprivacy/api/data_contracts/v1/data_contracts_v1.proto\x12!strmprivacy.api.data_contracts.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a google/protobuf/field_mask.proto\x1a-strmprivacy/api/entities/v1/entities_v1.proto\x1a\x17validate/validate.proto\"\x84\x03\n\x18ListDataContractsRequest\x12,\n\nbilling_id\x18\x01 \x01(\tB\r\x18\x01\xfa\x42\x08r\x06\x98\x01\x00\xd0\x01\x01R\tbillingId\x12\x16\n\x06\x66ilter\x18\x02 \x01(\tR\x06\x66ilter\x12\x16\n\x06handle\x18\x03 \x01(\tR\x06handle\x12\x12\n\x04name\x18\x04 \x01(\tR\x04name\x12W\n\x0epublic_private\x18\x05 \x01(\x0e\x32\x30.strmprivacy.api.entities.v1.FilterPublicPrivateR\rpublicPrivate\x12:\n\x06labels\x18\x07 \x03(\x0b\x32\".strmprivacy.api.entities.v1.LabelR\x06labels\x12\x18\n\x07\x64omains\x18\x08 \x03(\tR\x07\x64omains\x12\x1e\n\nindustries\x18\t \x03(\tR\nindustries\x12\'\n\nproject_id\x18\n \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01R\tprojectId\"\x9b\x03\n\x19ListDataContractsResponse\x12T\n\x0e\x64\x61ta_contracts\x18\x01 \x03(\x0b\x32).strmprivacy.api.entities.v1.DataContractB\x02\x18\x01R\rdataContracts\x12\x95\x01\n\x1c\x64\x61ta_contracts_and_checksums\x18\x02 \x03(\x0b\x32T.strmprivacy.api.data_contracts.v1.ListDataContractsResponse.DataContractAndChecksumR\x19\x64\x61taContractsAndChecksums\x1a\x8f\x01\n\x17\x44\x61taContractAndChecksum\x12S\n\rdata_contract\x18\x01 \x01(\x0b\x32).strmprivacy.api.entities.v1.DataContractB\x03\xe0\x41\x02R\x0c\x64\x61taContract\x12\x1f\n\x08\x63hecksum\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x08\x63hecksum\"\x96\x01\n\x16GetDataContractRequest\x12,\n\nbilling_id\x18\x01 \x01(\tB\r\x18\x01\xfa\x42\x08r\x06\x98\x01\x00\xd0\x01\x01R\tbillingId\x12>\n\x03ref\x18\x02 \x01(\x0b\x32,.strmprivacy.api.entities.v1.DataContractRefR\x03ref\x12\x0e\n\x02id\x18\x03 \x01(\tR\x02id\"\x8f\x01\n\x17GetDataContractResponse\x12S\n\rdata_contract\x18\x01 \x01(\x0b\x32).strmprivacy.api.entities.v1.DataContractB\x03\xe0\x41\x02R\x0c\x64\x61taContract\x12\x1f\n\x08\x63hecksum\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x08\x63hecksum\"\xcc\x01\n\x19\x43reateDataContractRequest\x12,\n\nbilling_id\x18\x01 \x01(\tB\r\x18\x01\xfa\x42\x08r\x06\x98\x01\x00\xd0\x01\x01R\tbillingId\x12X\n\rdata_contract\x18\x02 \x01(\x0b\x32).strmprivacy.api.entities.v1.DataContractB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x0c\x64\x61taContract\x12\'\n\nproject_id\x18\x03 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01R\tprojectId\"\x92\x01\n\x1a\x43reateDataContractResponse\x12S\n\rdata_contract\x18\x01 \x01(\x0b\x32).strmprivacy.api.entities.v1.DataContractB\x03\xe0\x41\x02R\x0c\x64\x61taContract\x12\x1f\n\x08\x63hecksum\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x08\x63hecksum\"\xfc\x03\n\x19UpdateDataContractRequest\x12,\n\nbilling_id\x18\x01 \x01(\tB\r\x18\x01\xfa\x42\x08r\x06\x98\x01\x00\xd0\x01\x01R\tbillingId\x12X\n\rdata_contract\x18\x02 \x01(\x0b\x32).strmprivacy.api.entities.v1.DataContractB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x0c\x64\x61taContract\x12#\n\x08\x63hecksum\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x08\x63hecksum\x12\x45\n\x0bupdate_mask\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\nupdateMask\x12~\n\x13\x63onsole_wizard_step\x18\x05 \x01(\x0e\x32N.strmprivacy.api.data_contracts.v1.UpdateDataContractRequest.ConsoleWizardStepR\x11\x63onsoleWizardStep\"k\n\x11\x43onsoleWizardStep\x12#\n\x1f\x43ONSOLE_WIZARD_STEP_UNSPECIFIED\x10\x00\x12\n\n\x06SCHEMA\x10\x01\x12\x12\n\x0e\x45VENT_CONTRACT\x10\x02\x12\x11\n\rDATA_CONTRACT\x10\x03\"\x92\x01\n\x1aUpdateDataContractResponse\x12S\n\rdata_contract\x18\x01 \x01(\x0b\x32).strmprivacy.api.entities.v1.DataContractB\x03\xe0\x41\x02R\x0c\x64\x61taContract\x12\x1f\n\x08\x63hecksum\x18\x02 \x01(\tB\x03\xe0\x41\x02R\x08\x63hecksum\"\xfb\x01\n\x19ReviewDataContractRequest\x12,\n\nbilling_id\x18\x01 \x01(\tB\r\x18\x01\xfa\x42\x08r\x06\x98\x01\x00\xd0\x01\x01R\tbillingId\x12\x0e\n\x02id\x18\x02 \x01(\tR\x02id\x12X\n\x11\x64\x61ta_contract_ref\x18\x03 \x01(\x0b\x32,.strmprivacy.api.entities.v1.DataContractRefR\x0f\x64\x61taContractRef\x12\x46\n\x19\x61pprover_external_user_id\x18\x04 \x01(\tB\x0b\xfa\x42\x08r\x06\xd0\x01\x01\xb0\x01\x01R\x16\x61pproverExternalUserId\"\x1c\n\x1aReviewDataContractResponse\"\xb5\x01\n\x1b\x41\x63tivateDataContractRequest\x12,\n\nbilling_id\x18\x01 \x01(\tB\r\x18\x01\xfa\x42\x08r\x06\x98\x01\x00\xd0\x01\x01R\tbillingId\x12\x0e\n\x02id\x18\x02 \x01(\tR\x02id\x12X\n\x11\x64\x61ta_contract_ref\x18\x03 \x01(\x0b\x32,.strmprivacy.api.entities.v1.DataContractRefR\x0f\x64\x61taContractRef\"\x1e\n\x1c\x41\x63tivateDataContractResponse\"\xdc\x01\n\x19\x44\x65leteDataContractRequest\x12,\n\nbilling_id\x18\x01 \x01(\tB\r\x18\x01\xfa\x42\x08r\x06\x98\x01\x00\xd0\x01\x01R\tbillingId\x12\x0e\n\x02id\x18\x02 \x01(\tR\x02id\x12\'\n\nproject_id\x18\x03 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01R\tprojectId\x12X\n\x11\x64\x61ta_contract_ref\x18\x04 \x01(\x0b\x32,.strmprivacy.api.entities.v1.DataContractRefR\x0f\x64\x61taContractRef\"\x1c\n\x1a\x44\x65leteDataContractResponse\"\xb4\x01\n\x1a\x41rchiveDataContractRequest\x12,\n\nbilling_id\x18\x01 \x01(\tB\r\x18\x01\xfa\x42\x08r\x06\x98\x01\x00\xd0\x01\x01R\tbillingId\x12\x0e\n\x02id\x18\x02 \x01(\tR\x02id\x12X\n\x11\x64\x61ta_contract_ref\x18\x03 \x01(\x0b\x32,.strmprivacy.api.entities.v1.DataContractRefR\x0f\x64\x61taContractRef\"\x1d\n\x1b\x41rchiveDataContractResponse\"\xb2\x01\n(ValidateDataContractsMaskedFieldsRequest\x12,\n\nbilling_id\x18\x01 \x01(\tB\r\x18\x01\xfa\x42\x08r\x06\x98\x01\x00\xd0\x01\x01R\tbillingId\x12X\n\rmasked_fields\x18\x02 \x01(\x0b\x32).strmprivacy.api.entities.v1.MaskedFieldsB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x0cmaskedFields\"\x92\x04\n)ValidateDataContractsMaskedFieldsResponse\x12j\n\x06\x65rrors\x18\x01 \x03(\x0b\x32R.strmprivacy.api.data_contracts.v1.ValidateDataContractsMaskedFieldsResponse.ErrorR\x06\x65rrors\x1a\xf8\x02\n\x05\x45rror\x12\x13\n\x02id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x02id\x12]\n\x11\x64\x61ta_contract_ref\x18\x02 \x01(\x0b\x32,.strmprivacy.api.entities.v1.DataContractRefB\x03\xe0\x41\x02R\x0f\x64\x61taContractRef\x12\x18\n\x07message\x18\x03 \x01(\tR\x07message\x12u\n\x06\x65rrors\x18\x04 \x03(\x0b\x32].strmprivacy.api.data_contracts.v1.ValidateDataContractsMaskedFieldsResponse.Error.FieldErrorR\x06\x65rrors\x1aj\n\nFieldError\x12#\n\rfield_pattern\x18\x01 \x01(\tR\x0c\x66ieldPattern\x12\x1d\n\nfield_type\x18\x02 \x01(\tR\tfieldType\x12\x18\n\x07message\x18\x03 \x01(\tR\x07message\"\xfd\x01\n GetDataContractSchemaCodeRequest\x12,\n\nbilling_id\x18\x01 \x01(\tB\r\x18\x01\xfa\x42\x08r\x06\x98\x01\x00\xd0\x01\x01R\tbillingId\x12\x0e\n\x02id\x18\x02 \x01(\tR\x02id\x12\x41\n\x08language\x18\x03 \x01(\tB%\xfa\x42\"r R\x04javaR\ntypescriptR\x06pythonR\x04rustR\x08language\x12X\n\x11\x64\x61ta_contract_ref\x18\x04 \x01(\x0b\x32,.strmprivacy.api.entities.v1.DataContractRefR\x0f\x64\x61taContractRef\"\x7f\n!GetDataContractSchemaCodeResponse\x12\x1f\n\x08\x66ilename\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x08\x66ilename\x12 \n\tdata_size\x18\x02 \x01(\x03\x42\x03\xe0\x41\x02R\x08\x64\x61taSize\x12\x17\n\x04\x64\x61ta\x18\x03 \x01(\x0c\x42\x03\xe0\x41\x02R\x04\x64\x61ta\"\x9a\x01\n&GetDataContractSchemaDefinitionRequest\x12!\n\x0c\x63onfluent_id\x18\x01 \x01(\x05R\x0b\x63onfluentId\x12M\n\x0b\x63luster_ref\x18\x02 \x01(\x0b\x32,.strmprivacy.api.entities.v1.KafkaClusterRefR\nclusterRef\"N\n\'GetDataContractSchemaDefinitionResponse\x12#\n\ndefinition\x18\x01 \x01(\tB\x03\xe0\x41\x02R\ndefinition\"\x9b\x01\n\x19SimpleSchemaDryRunRequest\x12~\n\x18simple_schema_definition\x18\x01 \x01(\x0b\x32:.strmprivacy.api.entities.v1.Schema.SimpleSchemaDefinitionB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x16simpleSchemaDefinition\"\x97\x01\n\x1aSimpleSchemaDryRunResponse\x12y\n\x18simple_schema_definition\x18\x01 \x01(\x0b\x32:.strmprivacy.api.entities.v1.Schema.SimpleSchemaDefinitionB\x03\xe0\x41\x02R\x16simpleSchemaDefinition2\xec\x0e\n\x14\x44\x61taContractsService\x12\x8e\x01\n\x11ListDataContracts\x12;.strmprivacy.api.data_contracts.v1.ListDataContractsRequest\x1a<.strmprivacy.api.data_contracts.v1.ListDataContractsResponse\x12\x88\x01\n\x0fGetDataContract\x12\x39.strmprivacy.api.data_contracts.v1.GetDataContractRequest\x1a:.strmprivacy.api.data_contracts.v1.GetDataContractResponse\x12\x91\x01\n\x12\x43reateDataContract\x12<.strmprivacy.api.data_contracts.v1.CreateDataContractRequest\x1a=.strmprivacy.api.data_contracts.v1.CreateDataContractResponse\x12\x91\x01\n\x12UpdateDataContract\x12<.strmprivacy.api.data_contracts.v1.UpdateDataContractRequest\x1a=.strmprivacy.api.data_contracts.v1.UpdateDataContractResponse\x12\x91\x01\n\x12ReviewDataContract\x12<.strmprivacy.api.data_contracts.v1.ReviewDataContractRequest\x1a=.strmprivacy.api.data_contracts.v1.ReviewDataContractResponse\x12\x97\x01\n\x14\x41\x63tivateDataContract\x12>.strmprivacy.api.data_contracts.v1.ActivateDataContractRequest\x1a?.strmprivacy.api.data_contracts.v1.ActivateDataContractResponse\x12\x91\x01\n\x12\x44\x65leteDataContract\x12<.strmprivacy.api.data_contracts.v1.DeleteDataContractRequest\x1a=.strmprivacy.api.data_contracts.v1.DeleteDataContractResponse\x12\x94\x01\n\x13\x41rchiveDataContract\x12=.strmprivacy.api.data_contracts.v1.ArchiveDataContractRequest\x1a>.strmprivacy.api.data_contracts.v1.ArchiveDataContractResponse\x12\xa6\x01\n\x19GetDataContractSchemaCode\x12\x43.strmprivacy.api.data_contracts.v1.GetDataContractSchemaCodeRequest\x1a\x44.strmprivacy.api.data_contracts.v1.GetDataContractSchemaCodeResponse\x12\xb8\x01\n\x1fGetDataContractSchemaDefinition\x12I.strmprivacy.api.data_contracts.v1.GetDataContractSchemaDefinitionRequest\x1aJ.strmprivacy.api.data_contracts.v1.GetDataContractSchemaDefinitionResponse\x12\xbe\x01\n!ValidateDataContractsMaskedFields\x12K.strmprivacy.api.data_contracts.v1.ValidateDataContractsMaskedFieldsRequest\x1aL.strmprivacy.api.data_contracts.v1.ValidateDataContractsMaskedFieldsResponse\x12\x91\x01\n\x12SimpleSchemaDryRun\x12<.strmprivacy.api.data_contracts.v1.SimpleSchemaDryRunRequest\x1a=.strmprivacy.api.data_contracts.v1.SimpleSchemaDryRunResponseB{\n$io.strmprivacy.api.data_contracts.v1P\x01ZQgithub.com/strmprivacy/api-definitions-go/v2/api/data_contracts/v1;data_contractsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.data_contracts.v1.data_contracts_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n$io.strmprivacy.api.data_contracts.v1P\001ZQgithub.com/strmprivacy/api-definitions-go/v2/api/data_contracts/v1;data_contracts'
  _LISTDATACONTRACTSREQUEST.fields_by_name['billing_id']._options = None
  _LISTDATACONTRACTSREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001\372B\010r\006\230\001\000\320\001\001'
  _LISTDATACONTRACTSREQUEST.fields_by_name['project_id']._options = None
  _LISTDATACONTRACTSREQUEST.fields_by_name['project_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _LISTDATACONTRACTSRESPONSE_DATACONTRACTANDCHECKSUM.fields_by_name['data_contract']._options = None
  _LISTDATACONTRACTSRESPONSE_DATACONTRACTANDCHECKSUM.fields_by_name['data_contract']._serialized_options = b'\340A\002'
  _LISTDATACONTRACTSRESPONSE_DATACONTRACTANDCHECKSUM.fields_by_name['checksum']._options = None
  _LISTDATACONTRACTSRESPONSE_DATACONTRACTANDCHECKSUM.fields_by_name['checksum']._serialized_options = b'\340A\002'
  _LISTDATACONTRACTSRESPONSE.fields_by_name['data_contracts']._options = None
  _LISTDATACONTRACTSRESPONSE.fields_by_name['data_contracts']._serialized_options = b'\030\001'
  _GETDATACONTRACTREQUEST.fields_by_name['billing_id']._options = None
  _GETDATACONTRACTREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001\372B\010r\006\230\001\000\320\001\001'
  _GETDATACONTRACTRESPONSE.fields_by_name['data_contract']._options = None
  _GETDATACONTRACTRESPONSE.fields_by_name['data_contract']._serialized_options = b'\340A\002'
  _GETDATACONTRACTRESPONSE.fields_by_name['checksum']._options = None
  _GETDATACONTRACTRESPONSE.fields_by_name['checksum']._serialized_options = b'\340A\002'
  _CREATEDATACONTRACTREQUEST.fields_by_name['billing_id']._options = None
  _CREATEDATACONTRACTREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001\372B\010r\006\230\001\000\320\001\001'
  _CREATEDATACONTRACTREQUEST.fields_by_name['data_contract']._options = None
  _CREATEDATACONTRACTREQUEST.fields_by_name['data_contract']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CREATEDATACONTRACTREQUEST.fields_by_name['project_id']._options = None
  _CREATEDATACONTRACTREQUEST.fields_by_name['project_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _CREATEDATACONTRACTRESPONSE.fields_by_name['data_contract']._options = None
  _CREATEDATACONTRACTRESPONSE.fields_by_name['data_contract']._serialized_options = b'\340A\002'
  _CREATEDATACONTRACTRESPONSE.fields_by_name['checksum']._options = None
  _CREATEDATACONTRACTRESPONSE.fields_by_name['checksum']._serialized_options = b'\340A\002'
  _UPDATEDATACONTRACTREQUEST.fields_by_name['billing_id']._options = None
  _UPDATEDATACONTRACTREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001\372B\010r\006\230\001\000\320\001\001'
  _UPDATEDATACONTRACTREQUEST.fields_by_name['data_contract']._options = None
  _UPDATEDATACONTRACTREQUEST.fields_by_name['data_contract']._serialized_options = b'\372B\005\212\001\002\020\001'
  _UPDATEDATACONTRACTREQUEST.fields_by_name['checksum']._options = None
  _UPDATEDATACONTRACTREQUEST.fields_by_name['checksum']._serialized_options = b'\372B\004r\002\020\001'
  _UPDATEDATACONTRACTREQUEST.fields_by_name['update_mask']._options = None
  _UPDATEDATACONTRACTREQUEST.fields_by_name['update_mask']._serialized_options = b'\372B\005\212\001\002\020\001'
  _UPDATEDATACONTRACTRESPONSE.fields_by_name['data_contract']._options = None
  _UPDATEDATACONTRACTRESPONSE.fields_by_name['data_contract']._serialized_options = b'\340A\002'
  _UPDATEDATACONTRACTRESPONSE.fields_by_name['checksum']._options = None
  _UPDATEDATACONTRACTRESPONSE.fields_by_name['checksum']._serialized_options = b'\340A\002'
  _REVIEWDATACONTRACTREQUEST.fields_by_name['billing_id']._options = None
  _REVIEWDATACONTRACTREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001\372B\010r\006\230\001\000\320\001\001'
  _REVIEWDATACONTRACTREQUEST.fields_by_name['approver_external_user_id']._options = None
  _REVIEWDATACONTRACTREQUEST.fields_by_name['approver_external_user_id']._serialized_options = b'\372B\010r\006\320\001\001\260\001\001'
  _ACTIVATEDATACONTRACTREQUEST.fields_by_name['billing_id']._options = None
  _ACTIVATEDATACONTRACTREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001\372B\010r\006\230\001\000\320\001\001'
  _DELETEDATACONTRACTREQUEST.fields_by_name['billing_id']._options = None
  _DELETEDATACONTRACTREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001\372B\010r\006\230\001\000\320\001\001'
  _DELETEDATACONTRACTREQUEST.fields_by_name['project_id']._options = None
  _DELETEDATACONTRACTREQUEST.fields_by_name['project_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _ARCHIVEDATACONTRACTREQUEST.fields_by_name['billing_id']._options = None
  _ARCHIVEDATACONTRACTREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001\372B\010r\006\230\001\000\320\001\001'
  _VALIDATEDATACONTRACTSMASKEDFIELDSREQUEST.fields_by_name['billing_id']._options = None
  _VALIDATEDATACONTRACTSMASKEDFIELDSREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001\372B\010r\006\230\001\000\320\001\001'
  _VALIDATEDATACONTRACTSMASKEDFIELDSREQUEST.fields_by_name['masked_fields']._options = None
  _VALIDATEDATACONTRACTSMASKEDFIELDSREQUEST.fields_by_name['masked_fields']._serialized_options = b'\372B\005\212\001\002\020\001'
  _VALIDATEDATACONTRACTSMASKEDFIELDSRESPONSE_ERROR.fields_by_name['id']._options = None
  _VALIDATEDATACONTRACTSMASKEDFIELDSRESPONSE_ERROR.fields_by_name['id']._serialized_options = b'\340A\002'
  _VALIDATEDATACONTRACTSMASKEDFIELDSRESPONSE_ERROR.fields_by_name['data_contract_ref']._options = None
  _VALIDATEDATACONTRACTSMASKEDFIELDSRESPONSE_ERROR.fields_by_name['data_contract_ref']._serialized_options = b'\340A\002'
  _GETDATACONTRACTSCHEMACODEREQUEST.fields_by_name['billing_id']._options = None
  _GETDATACONTRACTSCHEMACODEREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001\372B\010r\006\230\001\000\320\001\001'
  _GETDATACONTRACTSCHEMACODEREQUEST.fields_by_name['language']._options = None
  _GETDATACONTRACTSCHEMACODEREQUEST.fields_by_name['language']._serialized_options = b'\372B\"r R\004javaR\ntypescriptR\006pythonR\004rust'
  _GETDATACONTRACTSCHEMACODERESPONSE.fields_by_name['filename']._options = None
  _GETDATACONTRACTSCHEMACODERESPONSE.fields_by_name['filename']._serialized_options = b'\340A\002'
  _GETDATACONTRACTSCHEMACODERESPONSE.fields_by_name['data_size']._options = None
  _GETDATACONTRACTSCHEMACODERESPONSE.fields_by_name['data_size']._serialized_options = b'\340A\002'
  _GETDATACONTRACTSCHEMACODERESPONSE.fields_by_name['data']._options = None
  _GETDATACONTRACTSCHEMACODERESPONSE.fields_by_name['data']._serialized_options = b'\340A\002'
  _GETDATACONTRACTSCHEMADEFINITIONRESPONSE.fields_by_name['definition']._options = None
  _GETDATACONTRACTSCHEMADEFINITIONRESPONSE.fields_by_name['definition']._serialized_options = b'\340A\002'
  _SIMPLESCHEMADRYRUNREQUEST.fields_by_name['simple_schema_definition']._options = None
  _SIMPLESCHEMADRYRUNREQUEST.fields_by_name['simple_schema_definition']._serialized_options = b'\372B\005\212\001\002\020\001'
  _SIMPLESCHEMADRYRUNRESPONSE.fields_by_name['simple_schema_definition']._options = None
  _SIMPLESCHEMADRYRUNRESPONSE.fields_by_name['simple_schema_definition']._serialized_options = b'\340A\002'
  _LISTDATACONTRACTSREQUEST._serialized_start=236
  _LISTDATACONTRACTSREQUEST._serialized_end=624
  _LISTDATACONTRACTSRESPONSE._serialized_start=627
  _LISTDATACONTRACTSRESPONSE._serialized_end=1038
  _LISTDATACONTRACTSRESPONSE_DATACONTRACTANDCHECKSUM._serialized_start=895
  _LISTDATACONTRACTSRESPONSE_DATACONTRACTANDCHECKSUM._serialized_end=1038
  _GETDATACONTRACTREQUEST._serialized_start=1041
  _GETDATACONTRACTREQUEST._serialized_end=1191
  _GETDATACONTRACTRESPONSE._serialized_start=1194
  _GETDATACONTRACTRESPONSE._serialized_end=1337
  _CREATEDATACONTRACTREQUEST._serialized_start=1340
  _CREATEDATACONTRACTREQUEST._serialized_end=1544
  _CREATEDATACONTRACTRESPONSE._serialized_start=1547
  _CREATEDATACONTRACTRESPONSE._serialized_end=1693
  _UPDATEDATACONTRACTREQUEST._serialized_start=1696
  _UPDATEDATACONTRACTREQUEST._serialized_end=2204
  _UPDATEDATACONTRACTREQUEST_CONSOLEWIZARDSTEP._serialized_start=2097
  _UPDATEDATACONTRACTREQUEST_CONSOLEWIZARDSTEP._serialized_end=2204
  _UPDATEDATACONTRACTRESPONSE._serialized_start=2207
  _UPDATEDATACONTRACTRESPONSE._serialized_end=2353
  _REVIEWDATACONTRACTREQUEST._serialized_start=2356
  _REVIEWDATACONTRACTREQUEST._serialized_end=2607
  _REVIEWDATACONTRACTRESPONSE._serialized_start=2609
  _REVIEWDATACONTRACTRESPONSE._serialized_end=2637
  _ACTIVATEDATACONTRACTREQUEST._serialized_start=2640
  _ACTIVATEDATACONTRACTREQUEST._serialized_end=2821
  _ACTIVATEDATACONTRACTRESPONSE._serialized_start=2823
  _ACTIVATEDATACONTRACTRESPONSE._serialized_end=2853
  _DELETEDATACONTRACTREQUEST._serialized_start=2856
  _DELETEDATACONTRACTREQUEST._serialized_end=3076
  _DELETEDATACONTRACTRESPONSE._serialized_start=3078
  _DELETEDATACONTRACTRESPONSE._serialized_end=3106
  _ARCHIVEDATACONTRACTREQUEST._serialized_start=3109
  _ARCHIVEDATACONTRACTREQUEST._serialized_end=3289
  _ARCHIVEDATACONTRACTRESPONSE._serialized_start=3291
  _ARCHIVEDATACONTRACTRESPONSE._serialized_end=3320
  _VALIDATEDATACONTRACTSMASKEDFIELDSREQUEST._serialized_start=3323
  _VALIDATEDATACONTRACTSMASKEDFIELDSREQUEST._serialized_end=3501
  _VALIDATEDATACONTRACTSMASKEDFIELDSRESPONSE._serialized_start=3504
  _VALIDATEDATACONTRACTSMASKEDFIELDSRESPONSE._serialized_end=4034
  _VALIDATEDATACONTRACTSMASKEDFIELDSRESPONSE_ERROR._serialized_start=3658
  _VALIDATEDATACONTRACTSMASKEDFIELDSRESPONSE_ERROR._serialized_end=4034
  _VALIDATEDATACONTRACTSMASKEDFIELDSRESPONSE_ERROR_FIELDERROR._serialized_start=3928
  _VALIDATEDATACONTRACTSMASKEDFIELDSRESPONSE_ERROR_FIELDERROR._serialized_end=4034
  _GETDATACONTRACTSCHEMACODEREQUEST._serialized_start=4037
  _GETDATACONTRACTSCHEMACODEREQUEST._serialized_end=4290
  _GETDATACONTRACTSCHEMACODERESPONSE._serialized_start=4292
  _GETDATACONTRACTSCHEMACODERESPONSE._serialized_end=4419
  _GETDATACONTRACTSCHEMADEFINITIONREQUEST._serialized_start=4422
  _GETDATACONTRACTSCHEMADEFINITIONREQUEST._serialized_end=4576
  _GETDATACONTRACTSCHEMADEFINITIONRESPONSE._serialized_start=4578
  _GETDATACONTRACTSCHEMADEFINITIONRESPONSE._serialized_end=4656
  _SIMPLESCHEMADRYRUNREQUEST._serialized_start=4659
  _SIMPLESCHEMADRYRUNREQUEST._serialized_end=4814
  _SIMPLESCHEMADRYRUNRESPONSE._serialized_start=4817
  _SIMPLESCHEMADRYRUNRESPONSE._serialized_end=4968
  _DATACONTRACTSSERVICE._serialized_start=4971
  _DATACONTRACTSSERVICE._serialized_end=6871
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/schemas/v1/schemas_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+strmprivacy/api/schemas/v1/schemas_v1.proto\x12\x1astrmprivacy.api.schemas.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a google/protobuf/field_mask.proto\x1a-strmprivacy/api/entities/v1/entities_v1.proto\"\xbd\x03\n\x12ListSchemasRequest\x12\"\n\nbilling_id\x18\x01 \x01(\tB\x03\xe0\x41\x01R\tbillingId\x12\x1b\n\x06\x66ilter\x18\x02 \x01(\tB\x03\xe0\x41\x01R\x06\x66ilter\x12\x1b\n\x06handle\x18\x03 \x01(\tB\x03\xe0\x41\x01R\x06handle\x12\x17\n\x04name\x18\x04 \x01(\tB\x03\xe0\x41\x01R\x04name\x12\\\n\x0epublic_private\x18\x05 \x01(\x0e\x32\x30.strmprivacy.api.entities.v1.FilterPublicPrivateB\x03\xe0\x41\x01R\rpublicPrivate\x12M\n\x0bschema_type\x18\x06 \x01(\x0e\x32\'.strmprivacy.api.entities.v1.SchemaTypeB\x03\xe0\x41\x01R\nschemaType\x12?\n\x06labels\x18\x07 \x03(\x0b\x32\".strmprivacy.api.entities.v1.LabelB\x03\xe0\x41\x01R\x06labels\x12\x1d\n\x07\x64omains\x18\x08 \x03(\tB\x03\xe0\x41\x01R\x07\x64omains\x12#\n\nindustries\x18\t \x03(\tB\x03\xe0\x41\x01R\nindustries\"T\n\x13ListSchemasResponse\x12=\n\x07schemas\x18\x01 \x03(\x0b\x32#.strmprivacy.api.entities.v1.SchemaR\x07schemas\"\xbe\x01\n\x10GetSchemaRequest\x12!\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01R\tbillingId\x12\x38\n\x03ref\x18\x02 \x01(\x0b\x32&.strmprivacy.api.entities.v1.SchemaRefR\x03ref\x12M\n\x0b\x63luster_ref\x18\x03 \x01(\x0b\x32,.strmprivacy.api.entities.v1.KafkaClusterRefR\nclusterRef\"\x94\x01\n\x11GetSchemaResponse\x12;\n\x06schema\x18\x01 \x01(\x0b\x32#.strmprivacy.api.entities.v1.SchemaR\x06schema\x12!\n\x0c\x63onfluent_id\x18\x02 \x01(\x05R\x0b\x63onfluentId\x12\x1f\n\x08\x63hecksum\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x08\x63hecksum\"\x94\x01\n\x13\x43reateSchemaRequest\x12!\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01R\tbillingId\x12;\n\x06schema\x18\x02 \x01(\x0b\x32#.strmprivacy.api.entities.v1.SchemaR\x06schema\x12\x1d\n\nproject_id\x18\x03 \x01(\tR\tprojectId\"t\n\x14\x43reateSchemaResponse\x12;\n\x06schema\x18\x01 \x01(\x0b\x32#.strmprivacy.api.entities.v1.SchemaR\x06schema\x12\x1f\n\x08\x63hecksum\x18\x02 \x01(\tB\x03\xe0\x41\x03R\x08\x63hecksum\"\x81\x02\n\x13UpdateSchemaRequest\x12!\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01R\tbillingId\x12@\n\x06schema\x18\x02 \x01(\x0b\x32#.strmprivacy.api.entities.v1.SchemaB\x03\xe0\x41\x02R\x06schema\x12\x1f\n\x08\x63hecksum\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x08\x63hecksum\x12@\n\x0bupdate_mask\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x03\xe0\x41\x02R\nupdateMask\x12\"\n\nproject_id\x18\x05 \x01(\tB\x03\xe0\x41\x02R\tprojectId\"t\n\x14UpdateSchemaResponse\x12;\n\x06schema\x18\x01 \x01(\x0b\x32#.strmprivacy.api.entities.v1.SchemaR\x06schema\x12\x1f\n\x08\x63hecksum\x18\x02 \x01(\tB\x03\xe0\x41\x03R\x08\x63hecksum\"\xaa\x01\n\x15\x41\x63tivateSchemaRequest\x12!\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01R\tbillingId\x12J\n\nschema_ref\x18\x02 \x01(\x0b\x32&.strmprivacy.api.entities.v1.SchemaRefB\x03\xe0\x41\x02R\tschemaRef\x12\"\n\nproject_id\x18\x03 \x01(\tB\x03\xe0\x41\x02R\tprojectId\"\x18\n\x16\x41\x63tivateSchemaResponse\"\xa8\x01\n\x13\x44\x65leteSchemaRequest\x12!\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01R\tbillingId\x12J\n\nschema_ref\x18\x02 \x01(\x0b\x32&.strmprivacy.api.entities.v1.SchemaRefB\x03\xe0\x41\x02R\tschemaRef\x12\"\n\nproject_id\x18\x03 \x01(\tB\x03\xe0\x41\x02R\tprojectId\"\x16\n\x14\x44\x65leteSchemaResponse\"\xa9\x01\n\x14\x41rchiveSchemaRequest\x12!\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01R\tbillingId\x12J\n\nschema_ref\x18\x02 \x01(\x0b\x32&.strmprivacy.api.entities.v1.SchemaRefB\x03\xe0\x41\x02R\tschemaRef\x12\"\n\nproject_id\x18\x03 \x01(\tB\x03\xe0\x41\x02R\tprojectId\"\x17\n\x15\x41rchiveSchemaResponse\"\x8f\x01\n\x14GetSchemaCodeRequest\x12!\n\nbilling_id\x18\x01 \x01(\tB\x02\x18\x01R\tbillingId\x12\x38\n\x03ref\x18\x02 \x01(\x0b\x32&.strmprivacy.api.entities.v1.SchemaRefR\x03ref\x12\x1a\n\x08language\x18\x03 \x01(\tR\x08language\"d\n\x15GetSchemaCodeResponse\x12\x1a\n\x08\x66ilename\x18\x01 \x01(\tR\x08\x66ilename\x12\x1b\n\tdata_size\x18\x02 \x01(\x03R\x08\x64\x61taSize\x12\x12\n\x04\x64\x61ta\x18\x03 \x01(\x0cR\x04\x64\x61ta\"\x8e\x01\n\x1aGetSchemaDefinitionRequest\x12!\n\x0c\x63onfluent_id\x18\x01 \x01(\x05R\x0b\x63onfluentId\x12M\n\x0b\x63luster_ref\x18\x02 \x01(\x0b\x32,.strmprivacy.api.entities.v1.KafkaClusterRefR\nclusterRef\"=\n\x1bGetSchemaDefinitionResponse\x12\x1e\n\ndefinition\x18\x01 \x01(\tR\ndefinition2\xb1\x08\n\x0eSchemasService\x12n\n\x0bListSchemas\x12..strmprivacy.api.schemas.v1.ListSchemasRequest\x1a/.strmprivacy.api.schemas.v1.ListSchemasResponse\x12h\n\tGetSchema\x12,.strmprivacy.api.schemas.v1.GetSchemaRequest\x1a-.strmprivacy.api.schemas.v1.GetSchemaResponse\x12q\n\x0c\x43reateSchema\x12/.strmprivacy.api.schemas.v1.CreateSchemaRequest\x1a\x30.strmprivacy.api.schemas.v1.CreateSchemaResponse\x12q\n\x0cUpdateSchema\x12/.strmprivacy.api.schemas.v1.UpdateSchemaRequest\x1a\x30.strmprivacy.api.schemas.v1.UpdateSchemaResponse\x12t\n\rGetSchemaCode\x12\x30.strmprivacy.api.schemas.v1.GetSchemaCodeRequest\x1a\x31.strmprivacy.api.schemas.v1.GetSchemaCodeResponse\x12w\n\x0e\x41\x63tivateSchema\x12\x31.strmprivacy.api.schemas.v1.ActivateSchemaRequest\x1a\x32.strmprivacy.api.schemas.v1.ActivateSchemaResponse\x12q\n\x0c\x44\x65leteSchema\x12/.strmprivacy.api.schemas.v1.DeleteSchemaRequest\x1a\x30.strmprivacy.api.schemas.v1.DeleteSchemaResponse\x12t\n\rArchiveSchema\x12\x30.strmprivacy.api.schemas.v1.ArchiveSchemaRequest\x1a\x31.strmprivacy.api.schemas.v1.ArchiveSchemaResponse\x12\x86\x01\n\x13GetSchemaDefinition\x12\x36.strmprivacy.api.schemas.v1.GetSchemaDefinitionRequest\x1a\x37.strmprivacy.api.schemas.v1.GetSchemaDefinitionResponseBf\n\x1dio.strmprivacy.api.schemas.v1P\x01ZCgithub.com/strmprivacy/api-definitions-go/v2/api/schemas/v1;schemasb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.schemas.v1.schemas_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035io.strmprivacy.api.schemas.v1P\001ZCgithub.com/strmprivacy/api-definitions-go/v2/api/schemas/v1;schemas'
  _LISTSCHEMASREQUEST.fields_by_name['billing_id']._options = None
  _LISTSCHEMASREQUEST.fields_by_name['billing_id']._serialized_options = b'\340A\001'
  _LISTSCHEMASREQUEST.fields_by_name['filter']._options = None
  _LISTSCHEMASREQUEST.fields_by_name['filter']._serialized_options = b'\340A\001'
  _LISTSCHEMASREQUEST.fields_by_name['handle']._options = None
  _LISTSCHEMASREQUEST.fields_by_name['handle']._serialized_options = b'\340A\001'
  _LISTSCHEMASREQUEST.fields_by_name['name']._options = None
  _LISTSCHEMASREQUEST.fields_by_name['name']._serialized_options = b'\340A\001'
  _LISTSCHEMASREQUEST.fields_by_name['public_private']._options = None
  _LISTSCHEMASREQUEST.fields_by_name['public_private']._serialized_options = b'\340A\001'
  _LISTSCHEMASREQUEST.fields_by_name['schema_type']._options = None
  _LISTSCHEMASREQUEST.fields_by_name['schema_type']._serialized_options = b'\340A\001'
  _LISTSCHEMASREQUEST.fields_by_name['labels']._options = None
  _LISTSCHEMASREQUEST.fields_by_name['labels']._serialized_options = b'\340A\001'
  _LISTSCHEMASREQUEST.fields_by_name['domains']._options = None
  _LISTSCHEMASREQUEST.fields_by_name['domains']._serialized_options = b'\340A\001'
  _LISTSCHEMASREQUEST.fields_by_name['industries']._options = None
  _LISTSCHEMASREQUEST.fields_by_name['industries']._serialized_options = b'\340A\001'
  _GETSCHEMAREQUEST.fields_by_name['billing_id']._options = None
  _GETSCHEMAREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _GETSCHEMARESPONSE.fields_by_name['checksum']._options = None
  _GETSCHEMARESPONSE.fields_by_name['checksum']._serialized_options = b'\340A\002'
  _CREATESCHEMAREQUEST.fields_by_name['billing_id']._options = None
  _CREATESCHEMAREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _CREATESCHEMARESPONSE.fields_by_name['checksum']._options = None
  _CREATESCHEMARESPONSE.fields_by_name['checksum']._serialized_options = b'\340A\003'
  _UPDATESCHEMAREQUEST.fields_by_name['billing_id']._options = None
  _UPDATESCHEMAREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _UPDATESCHEMAREQUEST.fields_by_name['schema']._options = None
  _UPDATESCHEMAREQUEST.fields_by_name['schema']._serialized_options = b'\340A\002'
  _UPDATESCHEMAREQUEST.fields_by_name['checksum']._options = None
  _UPDATESCHEMAREQUEST.fields_by_name['checksum']._serialized_options = b'\340A\002'
  _UPDATESCHEMAREQUEST.fields_by_name['update_mask']._options = None
  _UPDATESCHEMAREQUEST.fields_by_name['update_mask']._serialized_options = b'\340A\002'
  _UPDATESCHEMAREQUEST.fields_by_name['project_id']._options = None
  _UPDATESCHEMAREQUEST.fields_by_name['project_id']._serialized_options = b'\340A\002'
  _UPDATESCHEMARESPONSE.fields_by_name['checksum']._options = None
  _UPDATESCHEMARESPONSE.fields_by_name['checksum']._serialized_options = b'\340A\003'
  _ACTIVATESCHEMAREQUEST.fields_by_name['billing_id']._options = None
  _ACTIVATESCHEMAREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _ACTIVATESCHEMAREQUEST.fields_by_name['schema_ref']._options = None
  _ACTIVATESCHEMAREQUEST.fields_by_name['schema_ref']._serialized_options = b'\340A\002'
  _ACTIVATESCHEMAREQUEST.fields_by_name['project_id']._options = None
  _ACTIVATESCHEMAREQUEST.fields_by_name['project_id']._serialized_options = b'\340A\002'
  _DELETESCHEMAREQUEST.fields_by_name['billing_id']._options = None
  _DELETESCHEMAREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _DELETESCHEMAREQUEST.fields_by_name['schema_ref']._options = None
  _DELETESCHEMAREQUEST.fields_by_name['schema_ref']._serialized_options = b'\340A\002'
  _DELETESCHEMAREQUEST.fields_by_name['project_id']._options = None
  _DELETESCHEMAREQUEST.fields_by_name['project_id']._serialized_options = b'\340A\002'
  _ARCHIVESCHEMAREQUEST.fields_by_name['billing_id']._options = None
  _ARCHIVESCHEMAREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _ARCHIVESCHEMAREQUEST.fields_by_name['schema_ref']._options = None
  _ARCHIVESCHEMAREQUEST.fields_by_name['schema_ref']._serialized_options = b'\340A\002'
  _ARCHIVESCHEMAREQUEST.fields_by_name['project_id']._options = None
  _ARCHIVESCHEMAREQUEST.fields_by_name['project_id']._serialized_options = b'\340A\002'
  _GETSCHEMACODEREQUEST.fields_by_name['billing_id']._options = None
  _GETSCHEMACODEREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001'
  _LISTSCHEMASREQUEST._serialized_start=190
  _LISTSCHEMASREQUEST._serialized_end=635
  _LISTSCHEMASRESPONSE._serialized_start=637
  _LISTSCHEMASRESPONSE._serialized_end=721
  _GETSCHEMAREQUEST._serialized_start=724
  _GETSCHEMAREQUEST._serialized_end=914
  _GETSCHEMARESPONSE._serialized_start=917
  _GETSCHEMARESPONSE._serialized_end=1065
  _CREATESCHEMAREQUEST._serialized_start=1068
  _CREATESCHEMAREQUEST._serialized_end=1216
  _CREATESCHEMARESPONSE._serialized_start=1218
  _CREATESCHEMARESPONSE._serialized_end=1334
  _UPDATESCHEMAREQUEST._serialized_start=1337
  _UPDATESCHEMAREQUEST._serialized_end=1594
  _UPDATESCHEMARESPONSE._serialized_start=1596
  _UPDATESCHEMARESPONSE._serialized_end=1712
  _ACTIVATESCHEMAREQUEST._serialized_start=1715
  _ACTIVATESCHEMAREQUEST._serialized_end=1885
  _ACTIVATESCHEMARESPONSE._serialized_start=1887
  _ACTIVATESCHEMARESPONSE._serialized_end=1911
  _DELETESCHEMAREQUEST._serialized_start=1914
  _DELETESCHEMAREQUEST._serialized_end=2082
  _DELETESCHEMARESPONSE._serialized_start=2084
  _DELETESCHEMARESPONSE._serialized_end=2106
  _ARCHIVESCHEMAREQUEST._serialized_start=2109
  _ARCHIVESCHEMAREQUEST._serialized_end=2278
  _ARCHIVESCHEMARESPONSE._serialized_start=2280
  _ARCHIVESCHEMARESPONSE._serialized_end=2303
  _GETSCHEMACODEREQUEST._serialized_start=2306
  _GETSCHEMACODEREQUEST._serialized_end=2449
  _GETSCHEMACODERESPONSE._serialized_start=2451
  _GETSCHEMACODERESPONSE._serialized_end=2551
  _GETSCHEMADEFINITIONREQUEST._serialized_start=2554
  _GETSCHEMADEFINITIONREQUEST._serialized_end=2696
  _GETSCHEMADEFINITIONRESPONSE._serialized_start=2698
  _GETSCHEMADEFINITIONRESPONSE._serialized_end=2759
  _SCHEMASSERVICE._serialized_start=2762
  _SCHEMASSERVICE._serialized_end=3835
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/installations/v1/entities_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2strmprivacy/api/installations/v1/entities_v1.proto\x12 strmprivacy.api.installations.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17validate/validate.proto\"\xbc\x02\n\x0cInstallation\x12\x18\n\x02id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01R\x02id\x12\x64\n\x11installation_type\x18\x02 \x01(\x0e\x32\x32.strmprivacy.api.installations.v1.InstallationTypeB\x03\xe0\x41\x02R\x10installationType\x12\x36\n\x12\x62illing_account_id\x18\x03 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01R\x10\x62illingAccountId\x12t\n\x18installation_credentials\x18\x04 \x01(\x0b\x32\x39.strmprivacy.api.installations.v1.InstallationCredentialsR\x17installationCredentials\"\x96\x01\n\x17InstallationCredentials\x12 \n\tclient_id\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x08\x63lientId\x12(\n\rclient_secret\x18\x02 \x01(\tB\x03\xe0\x41\x03R\x0c\x63lientSecret\x12/\n\x11image_pull_secret\x18\x03 \x01(\tB\x03\xe0\x41\x03R\x0fimagePullSecret\"\xdb\x01\n\x12InstalledComponent\x12i\n\x0e\x63omponent_type\x18\x01 \x01(\x0e\x32\x38.strmprivacy.api.installations.v1.InstalledComponentTypeB\x08\xfa\x42\x05\x82\x01\x02 \x00R\rcomponentType\x12Z\n\tinstances\x18\x02 \x03(\x0b\x32<.strmprivacy.api.installations.v1.InstalledComponentInstanceR\tinstances\"\x88\x01\n\x1aInstalledComponentInstance\x12\x17\n\x02id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x03R\x02id\x12Q\n\x06states\x18\x02 \x03(\x0b\x32\x39.strmprivacy.api.installations.v1.InstalledComponentStateR\x06states\"\xf4\x01\n\x1fInstalledComponentsCurrentState\x12i\n\x0e\x63omponent_type\x18\x01 \x01(\x0e\x32\x38.strmprivacy.api.installations.v1.InstalledComponentTypeB\x08\xfa\x42\x05\x82\x01\x02 \x00R\rcomponentType\x12\x66\n\tinstances\x18\x02 \x03(\x0b\x32H.strmprivacy.api.installations.v1.InstalledComponentInstanceCurrentStateR\tinstances\"\x92\x01\n&InstalledComponentInstanceCurrentState\x12\x17\n\x02id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x04R\x02id\x12O\n\x05state\x18\x02 \x01(\x0b\x32\x39.strmprivacy.api.installations.v1.InstalledComponentStateR\x05state\"\xe7\x01\n\x17InstalledComponentState\x12>\n\nstate_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\tstateTime\x12\x66\n\nstate_type\x18\x02 \x01(\x0e\x32=.strmprivacy.api.installations.v1.InstalledComponentStateTypeB\x08\xfa\x42\x05\x82\x01\x02 \x00R\tstateType\x12$\n\x07message\x18\x03 \x01(\tB\n\xfa\x42\x07r\x05\x10\x04\xd0\x01\x01R\x07message*\x7f\n\x10InstallationType\x12!\n\x1dINSTALLATION_TYPE_UNSPECIFIED\x10\x00\x12\x08\n\x04SAAS\x10\x01\x12\x0f\n\x0bSELF_HOSTED\x10\x02\x12\x13\n\x0f\x41WS_MARKETPLACE\x10\x03\x12\x18\n\x14\x41WS_MARKETPLACE_PAYG\x10\x04*\xfb\x01\n\x16InstalledComponentType\x12(\n$INSTALLED_COMPONENT_TYPE_UNSPECIFIED\x10\x00\x12\x14\n\x10\x42\x41TCH_JOBS_AGENT\x10\x01\x12\x19\n\x15\x42\x41TCH_EXPORTERS_AGENT\x10\x02\x12\x19\n\x15KAFKA_EXPORTERS_AGENT\x10\x03\x12\x11\n\rSTREAMS_AGENT\x10\x04\x12\x11\n\rEVENT_GATEWAY\x10\x05\x12\x0e\n\nWEB_SOCKET\x10\x06\x12\x19\n\x15\x44\x41TA_CONNECTORS_AGENT\x10\x07\x12\x1a\n\x16\x43ONFLUENT_SCHEMA_PROXY\x10\x08*\x89\x01\n\x1bInstalledComponentStateType\x12.\n*INSTALLED_COMPONENT_STATE_TYPE_UNSPECIFIED\x10\x00\x12\x0f\n\x0bPROVISIONED\x10\x01\x12\x0b\n\x07RUNNING\x10\x02\x12\t\n\x05\x45RROR\x10\x03\x12\x11\n\rSHUTTING_DOWN\x10\x04\x42x\n#io.strmprivacy.api.installations.v1P\x01ZOgithub.com/strmprivacy/api-definitions-go/v2/api/installations/v1;installationsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.installations.v1.entities_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#io.strmprivacy.api.installations.v1P\001ZOgithub.com/strmprivacy/api-definitions-go/v2/api/installations/v1;installations'
  _INSTALLATION.fields_by_name['id']._options = None
  _INSTALLATION.fields_by_name['id']._serialized_options = b'\372B\005r\003\260\001\001'
  _INSTALLATION.fields_by_name['installation_type']._options = None
  _INSTALLATION.fields_by_name['installation_type']._serialized_options = b'\340A\002'
  _INSTALLATION.fields_by_name['billing_account_id']._options = None
  _INSTALLATION.fields_by_name['billing_account_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _INSTALLATIONCREDENTIALS.fields_by_name['client_id']._options = None
  _INSTALLATIONCREDENTIALS.fields_by_name['client_id']._serialized_options = b'\340A\003'
  _INSTALLATIONCREDENTIALS.fields_by_name['client_secret']._options = None
  _INSTALLATIONCREDENTIALS.fields_by_name['client_secret']._serialized_options = b'\340A\003'
  _INSTALLATIONCREDENTIALS.fields_by_name['image_pull_secret']._options = None
  _INSTALLATIONCREDENTIALS.fields_by_name['image_pull_secret']._serialized_options = b'\340A\003'
  _INSTALLEDCOMPONENT.fields_by_name['component_type']._options = None
  _INSTALLEDCOMPONENT.fields_by_name['component_type']._serialized_options = b'\372B\005\202\001\002 \000'
  _INSTALLEDCOMPONENTINSTANCE.fields_by_name['id']._options = None
  _INSTALLEDCOMPONENTINSTANCE.fields_by_name['id']._serialized_options = b'\372B\004r\002\020\003'
  _INSTALLEDCOMPONENTSCURRENTSTATE.fields_by_name['component_type']._options = None
  _INSTALLEDCOMPONENTSCURRENTSTATE.fields_by_name['component_type']._serialized_options = b'\372B\005\202\001\002 \000'
  _INSTALLEDCOMPONENTINSTANCECURRENTSTATE.fields_by_name['id']._options = None
  _INSTALLEDCOMPONENTINSTANCECURRENTSTATE.fields_by_name['id']._serialized_options = b'\372B\004r\002\020\004'
  _INSTALLEDCOMPONENTSTATE.fields_by_name['state_time']._options = None
  _INSTALLEDCOMPONENTSTATE.fields_by_name['state_time']._serialized_options = b'\340A\003'
  _INSTALLEDCOMPONENTSTATE.fields_by_name['state_type']._options = None
  _INSTALLEDCOMPONENTSTATE.fields_by_name['state_type']._serialized_options = b'\372B\005\202\001\002 \000'
  _INSTALLEDCOMPONENTSTATE.fields_by_name['message']._options = None
  _INSTALLEDCOMPONENTSTATE.fields_by_name['message']._serialized_options = b'\372B\007r\005\020\004\320\001\001'
  _INSTALLATIONTYPE._serialized_start=1642
  _INSTALLATIONTYPE._serialized_end=1769
  _INSTALLEDCOMPONENTTYPE._serialized_start=1772
  _INSTALLEDCOMPONENTTYPE._serialized_end=2023
  _INSTALLEDCOMPONENTSTATETYPE._serialized_start=2026
  _INSTALLEDCOMPONENTSTATETYPE._serialized_end=2163
  _INSTALLATION._serialized_start=180
  _INSTALLATION._serialized_end=496
  _INSTALLATIONCREDENTIALS._serialized_start=499
  _INSTALLATIONCREDENTIALS._serialized_end=649
  _INSTALLEDCOMPONENT._serialized_start=652
  _INSTALLEDCOMPONENT._serialized_end=871
  _INSTALLEDCOMPONENTINSTANCE._serialized_start=874
  _INSTALLEDCOMPONENTINSTANCE._serialized_end=1010
  _INSTALLEDCOMPONENTSCURRENTSTATE._serialized_start=1013
  _INSTALLEDCOMPONENTSCURRENTSTATE._serialized_end=1257
  _INSTALLEDCOMPONENTINSTANCECURRENTSTATE._serialized_start=1260
  _INSTALLEDCOMPONENTINSTANCECURRENTSTATE._serialized_end=1406
  _INSTALLEDCOMPONENTSTATE._serialized_start=1409
  _INSTALLEDCOMPONENTSTATE._serialized_end=1640
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/streams/v1/streams_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+strmprivacy/api/streams/v1/streams_v1.proto\x12\x1astrmprivacy.api.streams.v1\x1a-strmprivacy/api/entities/v1/entities_v1.proto\x1a\x17validate/validate.proto\"\x89\x01\n\x12ListStreamsRequest\x12,\n\nbilling_id\x18\x01 \x01(\tB\r\x18\x01\xfa\x42\x08r\x06\x98\x01\x00\xd0\x01\x01R\tbillingId\x12\x1c\n\trecursive\x18\x02 \x01(\x08R\trecursive\x12\'\n\nproject_id\x18\x03 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01R\tprojectId\"X\n\x13ListStreamsResponse\x12\x41\n\x07streams\x18\x01 \x03(\x0b\x32\'.strmprivacy.api.entities.v1.StreamTreeR\x07streams\"E\n\x1aListExtendedStreamsRequest\x12\'\n\nclient_ids\x18\x01 \x03(\tB\x08\xfa\x42\x05\x92\x01\x02\x08\x01R\tclientIds\"u\n\x1bListExtendedStreamsResponse\x12V\n\x10\x65xtended_streams\x18\x01 \x03(\x0b\x32+.strmprivacy.api.entities.v1.ExtendedStreamR\x0f\x65xtendedStreams\"w\n\x13\x44\x65leteStreamRequest\x12\x42\n\x03ref\x18\x01 \x01(\x0b\x32&.strmprivacy.api.entities.v1.StreamRefB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x03ref\x12\x1c\n\trecursive\x18\x02 \x01(\x08R\trecursive\"\x16\n\x14\x44\x65leteStreamResponse\"\\\n\x13\x43reateStreamRequest\x12\x45\n\x06stream\x18\x01 \x01(\x0b\x32#.strmprivacy.api.entities.v1.StreamB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x06stream\"S\n\x14\x43reateStreamResponse\x12;\n\x06stream\x18\x01 \x01(\x0b\x32#.strmprivacy.api.entities.v1.StreamR\x06stream\"t\n\x10GetStreamRequest\x12\x42\n\x03ref\x18\x01 \x01(\x0b\x32&.strmprivacy.api.entities.v1.StreamRefB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x03ref\x12\x1c\n\trecursive\x18\x02 \x01(\x08R\trecursive\"]\n\x11GetStreamResponse\x12H\n\x0bstream_tree\x18\x01 \x01(\x0b\x32\'.strmprivacy.api.entities.v1.StreamTreeR\nstreamTree2\xd9\x04\n\x0eStreamsService\x12n\n\x0bListStreams\x12..strmprivacy.api.streams.v1.ListStreamsRequest\x1a/.strmprivacy.api.streams.v1.ListStreamsResponse\x12\x86\x01\n\x13ListExtendedStreams\x12\x36.strmprivacy.api.streams.v1.ListExtendedStreamsRequest\x1a\x37.strmprivacy.api.streams.v1.ListExtendedStreamsResponse\x12h\n\tGetStream\x12,.strmprivacy.api.streams.v1.GetStreamRequest\x1a-.strmprivacy.api.streams.v1.GetStreamResponse\x12q\n\x0c\x44\x65leteStream\x12/.strmprivacy.api.streams.v1.DeleteStreamRequest\x1a\x30.strmprivacy.api.streams.v1.DeleteStreamResponse\x12q\n\x0c\x43reateStream\x12/.strmprivacy.api.streams.v1.CreateStreamRequest\x1a\x30.strmprivacy.api.streams.v1.CreateStreamResponseBf\n\x1dio.strmprivacy.api.streams.v1P\x01ZCgithub.com/strmprivacy/api-definitions-go/v2/api/streams/v1;streamsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.streams.v1.streams_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035io.strmprivacy.api.streams.v1P\001ZCgithub.com/strmprivacy/api-definitions-go/v2/api/streams/v1;streams'
  _LISTSTREAMSREQUEST.fields_by_name['billing_id']._options = None
  _LISTSTREAMSREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001\372B\010r\006\230\001\000\320\001\001'
  _LISTSTREAMSREQUEST.fields_by_name['project_id']._options = None
  _LISTSTREAMSREQUEST.fields_by_name['project_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _LISTEXTENDEDSTREAMSREQUEST.fields_by_name['client_ids']._options = None
  _LISTEXTENDEDSTREAMSREQUEST.fields_by_name['client_ids']._serialized_options = b'\372B\005\222\001\002\010\001'
  _DELETESTREAMREQUEST.fields_by_name['ref']._options = None
  _DELETESTREAMREQUEST.fields_by_name['ref']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CREATESTREAMREQUEST.fields_by_name['stream']._options = None
  _CREATESTREAMREQUEST.fields_by_name['stream']._serialized_options = b'\372B\005\212\001\002\020\001'
  _GETSTREAMREQUEST.fields_by_name['ref']._options = None
  _GETSTREAMREQUEST.fields_by_name['ref']._serialized_options = b'\372B\005\212\001\002\020\001'
  _LISTSTREAMSREQUEST._serialized_start=148
  _LISTSTREAMSREQUEST._serialized_end=285
  _LISTSTREAMSRESPONSE._serialized_start=287
  _LISTSTREAMSRESPONSE._serialized_end=375
  _LISTEXTENDEDSTREAMSREQUEST._serialized_start=377
  _LISTEXTENDEDSTREAMSREQUEST._serialized_end=446
  _LISTEXTENDEDSTREAMSRESPONSE._serialized_start=448
  _LISTEXTENDEDSTREAMSRESPONSE._serialized_end=565
  _DELETESTREAMREQUEST._serialized_start=567
  _DELETESTREAMREQUEST._serialized_end=686
  _DELETESTREAMRESPONSE._serialized_start=688
  _DELETESTREAMRESPONSE._serialized_end=710
  _CREATESTREAMREQUEST._serialized_start=712
  _CREATESTREAMREQUEST._serialized_end=804
  _CREATESTREAMRESPONSE._serialized_start=806
  _CREATESTREAMRESPONSE._serialized_end=889
  _GETSTREAMREQUEST._serialized_start=891
  _GETSTREAMREQUEST._serialized_end=1007
  _GETSTREAMRESPONSE._serialized_start=1009
  _GETSTREAMRESPONSE._serialized_end=1102
  _STREAMSSERVICE._serialized_start=1105
  _STREAMSSERVICE._serialized_end=1706
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/installations/v1/installed_components_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from strmprivacy.api.installations.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_installations_dot_v1_dot_entities__v1__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>strmprivacy/api/installations/v1/installed_components_v1.proto\x12 strmprivacy.api.installations.v1\x1a\x32strmprivacy/api/installations/v1/entities_v1.proto\x1a\x17validate/validate.proto\"\xef\x02\n$UpdateInstalledComponentStateRequest\x12i\n\x0e\x63omponent_type\x18\x01 \x01(\x0e\x32\x38.strmprivacy.api.installations.v1.InstalledComponentTypeB\x08\xfa\x42\x05\x82\x01\x02 \x00R\rcomponentType\x12(\n\x0binstance_id\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x04R\ninstanceId\x12\x7f\n\x19installed_component_state\x18\x03 \x01(\x0b\x32\x39.strmprivacy.api.installations.v1.InstalledComponentStateB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x17installedComponentState\x12\x31\n\x0finstallation_id\x18\x04 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01R\x0einstallationId\"\'\n%UpdateInstalledComponentStateResponse\"\xcf\x01\n\x1cGetInstalledComponentRequest\x12\x31\n\x0finstallation_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01R\x0einstallationId\x12|\n\x18installed_component_type\x18\x02 \x01(\x0e\x32\x38.strmprivacy.api.installations.v1.InstalledComponentTypeB\x08\xfa\x42\x05\x82\x01\x02 \x00R\x16installedComponentType\"\x86\x01\n\x1dGetInstalledComponentResponse\x12\x65\n\x13installed_component\x18\x01 \x01(\x0b\x32\x34.strmprivacy.api.installations.v1.InstalledComponentR\x12installedComponent\"S\n\x1eListInstalledComponentsRequest\x12\x31\n\x0finstallation_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01R\x0einstallationId\"\x8a\x01\n\x1fListInstalledComponentsResponse\x12g\n\x14installed_components\x18\x01 \x03(\x0b\x32\x34.strmprivacy.api.installations.v1.InstalledComponentR\x13installedComponents\"`\n+ListInstalledComponentsCurrentStatesRequest\x12\x31\n\x0finstallation_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01R\x0einstallationId\"\xa4\x01\n,ListInstalledComponentsCurrentStatesResponse\x12t\n\x14installed_components\x18\x01 \x03(\x0b\x32\x41.strmprivacy.api.installations.v1.InstalledComponentsCurrentStateR\x13installedComponents2\xd3\x05\n\x1aInstalledComponentsService\x12\xb0\x01\n\x1dUpdateInstalledComponentState\x12\x46.strmprivacy.api.installations.v1.UpdateInstalledComponentStateRequest\x1aG.strmprivacy.api.installations.v1.UpdateInstalledComponentStateResponse\x12\x98\x01\n\x15GetInstalledComponent\x12>.strmprivacy.api.installations.v1.GetInstalledComponentRequest\x1a?.strmprivacy.api.installations.v1.GetInstalledComponentResponse\x12\x9e\x01\n\x17ListInstalledComponents\x12@.strmprivacy.api.installations.v1.ListInstalledComponentsRequest\x1a\x41.strmprivacy.api.installations.v1.ListInstalledComponentsResponse\x12\xc5\x01\n$ListInstalledComponentsCurrentStates\x12M.strmprivacy.api.installations.v1.ListInstalledComponentsCurrentStatesRequest\x1aN.strmprivacy.api.installations.v1.ListInstalledComponentsCurrentStatesResponseBx\n#io.strmprivacy.api.installations.v1P\x01ZOgithub.com/strmprivacy/api-definitions-go/v2/api/installations/v1;installationsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.installations.v1.installed_components_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#io.strmprivacy.api.installations.v1P\001ZOgithub.com/strmprivacy/api-definitions-go/v2/api/installations/v1;installations'
  _UPDATEINSTALLEDCOMPONENTSTATEREQUEST.fields_by_name['component_type']._options = None
  _UPDATEINSTALLEDCOMPONENTSTATEREQUEST.fields_by_name['component_type']._serialized_options = b'\372B\005\202\001\002 \000'
  _UPDATEINSTALLEDCOMPONENTSTATEREQUEST.fields_by_name['instance_id']._options = None
  _UPDATEINSTALLEDCOMPONENTSTATEREQUEST.fields_by_name['instance_id']._serialized_options = b'\372B\004r\002\020\004'
  _UPDATEINSTALLEDCOMPONENTSTATEREQUEST.fields_by_name['installed_component_state']._options = None
  _UPDATEINSTALLEDCOMPONENTSTATEREQUEST.fields_by_name['installed_component_state']._serialized_options = b'\372B\005\212\001\002\020\001'
  _UPDATEINSTALLEDCOMPONENTSTATEREQUEST.fields_by_name['installation_id']._options = None
  _UPDATEINSTALLEDCOMPONENTSTATEREQUEST.fields_by_name['installation_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _GETINSTALLEDCOMPONENTREQUEST.fields_by_name['installation_id']._options = None
  _GETINSTALLEDCOMPONENTREQUEST.fields_by_name['installation_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _GETINSTALLEDCOMPONENTREQUEST.fields_by_name['installed_component_type']._options = None
  _GETINSTALLEDCOMPONENTREQUEST.fields_by_name['installed_component_type']._serialized_options = b'\372B\005\202\001\002 \000'
  _LISTINSTALLEDCOMPONENTSREQUEST.fields_by_name['installation_id']._options = None
  _LISTINSTALLEDCOMPONENTSREQUEST.fields_by_name['installation_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _LISTINSTALLEDCOMPONENTSCURRENTSTATESREQUEST.fields_by_name['installation_id']._options = None
  _LISTINSTALLEDCOMPONENTSCURRENTSTATESREQUEST.fields_by_name['installation_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _UPDATEINSTALLEDCOMPONENTSTATEREQUEST._serialized_start=178
  _UPDATEINSTALLEDCOMPONENTSTATEREQUEST._serialized_end=545
  _UPDATEINSTALLEDCOMPONENTSTATERESPONSE._serialized_start=547
  _UPDATEINSTALLEDCOMPONENTSTATERESPONSE._serialized_end=586
  _GETINSTALLEDCOMPONENTREQUEST._serialized_start=589
  _GETINSTALLEDCOMPONENTREQUEST._serialized_end=796
  _GETINSTALLEDCOMPONENTRESPONSE._serialized_start=799
  _GETINSTALLEDCOMPONENTRESPONSE._serialized_end=933
  _LISTINSTALLEDCOMPONENTSREQUEST._serialized_start=935
  _LISTINSTALLEDCOMPONENTSREQUEST._serialized_end=1018
  _LISTINSTALLEDCOMPONENTSRESPONSE._serialized_start=1021
  _LISTINSTALLEDCOMPONENTSRESPONSE._serialized_end=1159
  _LISTINSTALLEDCOMPONENTSCURRENTSTATESREQUEST._serialized_start=1161
  _LISTINSTALLEDCOMPONENTSCURRENTSTATESREQUEST._serialized_end=1257
  _LISTINSTALLEDCOMPONENTSCURRENTSTATESRESPONSE._serialized_start=1260
  _LISTINSTALLEDCOMPONENTSCURRENTSTATESRESPONSE._serialized_end=1424
  _INSTALLEDCOMPONENTSSERVICE._serialized_start=1427
  _INSTALLEDCOMPONENTSSERVICE._serialized_end=2150
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/kafka_users/v1/kafka_users_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3strmprivacy/api/kafka_users/v1/kafka_users_v1.proto\x12\x1estrmprivacy.api.kafka_users.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a-strmprivacy/api/entities/v1/entities_v1.proto\x1a\x17validate/validate.proto\"b\n\x15ListKafkaUsersRequest\x12I\n\x03ref\x18\x01 \x01(\x0b\x32-.strmprivacy.api.entities.v1.KafkaExporterRefB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x03ref\"f\n\x16ListKafkaUsersResponse\x12L\n\x0bkafka_users\x18\x01 \x03(\x0b\x32&.strmprivacy.api.entities.v1.KafkaUserB\x03\xe0\x41\x02R\nkafkaUsers\"_\n\x16\x44\x65leteKafkaUserRequest\x12\x45\n\x03ref\x18\x01 \x01(\x0b\x32).strmprivacy.api.entities.v1.KafkaUserRefB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x03ref\"\x19\n\x17\x44\x65leteKafkaUserResponse\"i\n\x16\x43reateKafkaUserRequest\x12O\n\nkafka_user\x18\x01 \x01(\x0b\x32&.strmprivacy.api.entities.v1.KafkaUserB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\tkafkaUser\"e\n\x17\x43reateKafkaUserResponse\x12J\n\nkafka_user\x18\x01 \x01(\x0b\x32&.strmprivacy.api.entities.v1.KafkaUserB\x03\xe0\x41\x02R\tkafkaUser\"\\\n\x13GetKafkaUserRequest\x12\x45\n\x03ref\x18\x01 \x01(\x0b\x32).strmprivacy.api.entities.v1.KafkaUserRefB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x03ref\"b\n\x14GetKafkaUserResponse\x12J\n\nkafka_user\x18\x01 \x01(\x0b\x32&.strmprivacy.api.entities.v1.KafkaUserB\x03\xe0\x41\x02R\tkafkaUser2\x99\x04\n\x11KafkaUsersService\x12\x7f\n\x0eListKafkaUsers\x12\x35.strmprivacy.api.kafka_users.v1.ListKafkaUsersRequest\x1a\x36.strmprivacy.api.kafka_users.v1.ListKafkaUsersResponse\x12y\n\x0cGetKafkaUser\x12\x33.strmprivacy.api.kafka_users.v1.GetKafkaUserRequest\x1a\x34.strmprivacy.api.kafka_users.v1.GetKafkaUserResponse\x12\x82\x01\n\x0f\x44\x65leteKafkaUser\x12\x36.strmprivacy.api.kafka_users.v1.DeleteKafkaUserRequest\x1a\x37.strmprivacy.api.kafka_users.v1.DeleteKafkaUserResponse\x12\x82\x01\n\x0f\x43reateKafkaUser\x12\x36.strmprivacy.api.kafka_users.v1.CreateKafkaUserRequest\x1a\x37.strmprivacy.api.kafka_users.v1.CreateKafkaUserResponseBr\n!io.strmprivacy.api.kafka_users.v1P\x01ZKgithub.com/strmprivacy/api-definitions-go/v2/api/kafka_users/v1;kafka_usersb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.kafka_users.v1.kafka_users_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!io.strmprivacy.api.kafka_users.v1P\001ZKgithub.com/strmprivacy/api-definitions-go/v2/api/kafka_users/v1;kafka_users'
  _LISTKAFKAUSERSREQUEST.fields_by_name['ref']._options = None
  _LISTKAFKAUSERSREQUEST.fields_by_name['ref']._serialized_options = b'\372B\005\212\001\002\020\001'
  _LISTKAFKAUSERSRESPONSE.fields_by_name['kafka_users']._options = None
  _LISTKAFKAUSERSRESPONSE.fields_by_name['kafka_users']._serialized_options = b'\340A\002'
  _DELETEKAFKAUSERREQUEST.fields_by_name['ref']._options = None
  _DELETEKAFKAUSERREQUEST.fields_by_name['ref']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CREATEKAFKAUSERREQUEST.fields_by_name['kafka_user']._options = None
  _CREATEKAFKAUSERREQUEST.fields_by_name['kafka_user']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CREATEKAFKAUSERRESPONSE.fields_by_name['kafka_user']._options = None
  _CREATEKAFKAUSERRESPONSE.fields_by_name['kafka_user']._serialized_options = b'\340A\002'
  _GETKAFKAUSERREQUEST.fields_by_name['ref']._options = None
  _GETKAFKAUSERREQUEST.fields_by_name['ref']._serialized_options = b'\372B\005\212\001\002\020\001'
  _GETKAFKAUSERRESPONSE.fields_by_name['kafka_user']._options = None
  _GETKAFKAUSERRESPONSE.fields_by_name['kafka_user']._serialized_options = b'\340A\002'
  _LISTKAFKAUSERSREQUEST._serialized_start=192
  _LISTKAFKAUSERSREQUEST._serialized_end=290
  _LISTKAFKAUSERSRESPONSE._serialized_start=292
  _LISTKAFKAUSERSRESPONSE._serialized_end=394
  _DELETEKAFKAUSERREQUEST._serialized_start=396
  _DELETEKAFKAUSERREQUEST._serialized_end=491
  _DELETEKAFKAUSERRESPONSE._serialized_start=493
  _DELETEKAFKAUSERRESPONSE._serialized_end=518
  _CREATEKAFKAUSERREQUEST._serialized_start=520
  _CREATEKAFKAUSERREQUEST._serialized_end=625
  _CREATEKAFKAUSERRESPONSE._serialized_start=627
  _CREATEKAFKAUSERRESPONSE._serialized_end=728
  _GETKAFKAUSERREQUEST._serialized_start=730
  _GETKAFKAUSERREQUEST._serialized_end=822
  _GETKAFKAUSERRESPONSE._serialized_start=824
  _GETKAFKAUSERRESPONSE._serialized_end=922
  _KAFKAUSERSSERVICE._serialized_start=925
  _KAFKAUSERSSERVICE._serialized_end=1462
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/organizations/v1/organizations_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7strmprivacy/api/organizations/v1/organizations_v1.proto\x12 strmprivacy.api.organizations.v1\x1a-strmprivacy/api/entities/v1/entities_v1.proto\x1a\x17validate/validate.proto\"\xa8\x01\n\x12InviteUsersRequest\x12\\\n\x0cuser_invites\x18\x01 \x03(\x0b\x32,.strmprivacy.api.organizations.v1.UserInviteB\x0b\xfa\x42\x08\x92\x01\x05\x08\x01\x10\xf4\x03R\x0buserInvites\x12\x34\n\x0forganization_id\x18\x02 \x01(\tB\x0b\xfa\x42\x08r\x06\xd0\x01\x01\xb0\x01\x01R\x0eorganizationId\"+\n\nUserInvite\x12\x1d\n\x05\x65mail\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02`\x01R\x05\x65mail\"\x94\x02\n\x13InviteUsersResponse\x12!\n\x0cinvite_count\x18\x01 \x01(\x03R\x0binviteCount\x12]\n\x06issues\x18\x02 \x03(\x0b\x32\x45.strmprivacy.api.organizations.v1.InviteUsersResponse.UserInviteIssueR\x06issues\x1a{\n\x0fUserInviteIssue\x12N\n\x06invite\x18\x01 \x01(\x0b\x32,.strmprivacy.api.organizations.v1.UserInviteB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x06invite\x12\x18\n\x07message\x18\x02 \x01(\tR\x07message\"\x86\x01\n\x16UpdateUserRolesRequest\x12&\n\x06\x65mails\x18\x01 \x03(\tB\x0e\xfa\x42\x0b\x92\x01\x08\x08\x01\"\x04r\x02`\x01R\x06\x65mails\x12\x44\n\nuser_roles\x18\x02 \x03(\x0e\x32%.strmprivacy.api.entities.v1.UserRoleR\tuserRoles\"\x19\n\x17UpdateUserRolesResponse\" \n\x1eListOrganizationMembersRequest\"w\n\x1fListOrganizationMembersResponse\x12T\n\x14organization_members\x18\x01 \x03(\x0b\x32!.strmprivacy.api.entities.v1.UserR\x13organizationMembers\"/\n\x0eGetUserRequest\x12\x1d\n\x05\x65mail\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02`\x01R\x05\x65mail\"H\n\x0fGetUserResponse\x12\x35\n\x04user\x18\x01 \x01(\x0b\x32!.strmprivacy.api.entities.v1.UserR\x04user2\xac\x04\n\x14OrganizationsService\x12z\n\x0bInviteUsers\x12\x34.strmprivacy.api.organizations.v1.InviteUsersRequest\x1a\x35.strmprivacy.api.organizations.v1.InviteUsersResponse\x12\x86\x01\n\x0fUpdateUserRoles\x12\x38.strmprivacy.api.organizations.v1.UpdateUserRolesRequest\x1a\x39.strmprivacy.api.organizations.v1.UpdateUserRolesResponse\x12n\n\x07GetUser\x12\x30.strmprivacy.api.organizations.v1.GetUserRequest\x1a\x31.strmprivacy.api.organizations.v1.GetUserResponse\x12\x9e\x01\n\x17ListOrganizationMembers\x12@.strmprivacy.api.organizations.v1.ListOrganizationMembersRequest\x1a\x41.strmprivacy.api.organizations.v1.ListOrganizationMembersResponseBx\n#io.strmprivacy.api.organizations.v1P\x01ZOgithub.com/strmprivacy/api-definitions-go/v2/api/organizations/v1;organizationsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.organizations.v1.organizations_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#io.strmprivacy.api.organizations.v1P\001ZOgithub.com/strmprivacy/api-definitions-go/v2/api/organizations/v1;organizations'
  _INVITEUSERSREQUEST.fields_by_name['user_invites']._options = None
  _INVITEUSERSREQUEST.fields_by_name['user_invites']._serialized_options = b'\372B\010\222\001\005\010\001\020\364\003'
  _INVITEUSERSREQUEST.fields_by_name['organization_id']._options = None
  _INVITEUSERSREQUEST.fields_by_name['organization_id']._serialized_options = b'\372B\010r\006\320\001\001\260\001\001'
  _USERINVITE.fields_by_name['email']._options = None
  _USERINVITE.fields_by_name['email']._serialized_options = b'\372B\004r\002`\001'
  _INVITEUSERSRESPONSE_USERINVITEISSUE.fields_by_name['invite']._options = None
  _INVITEUSERSRESPONSE_USERINVITEISSUE.fields_by_name['invite']._serialized_options = b'\372B\005\212\001\002\020\001'
  _UPDATEUSERROLESREQUEST.fields_by_name['emails']._options = None
  _UPDATEUSERROLESREQUEST.fields_by_name['emails']._serialized_options = b'\372B\013\222\001\010\010\001\"\004r\002`\001'
  _GETUSERREQUEST.fields_by_name['email']._options = None
  _GETUSERREQUEST.fields_by_name['email']._serialized_options = b'\372B\004r\002`\001'
  _INVITEUSERSREQUEST._serialized_start=166
  _INVITEUSERSREQUEST._serialized_end=334
  _USERINVITE._serialized_start=336
  _USERINVITE._serialized_end=379
  _INVITEUSERSRESPONSE._serialized_start=382
  _INVITEUSERSRESPONSE._serialized_end=658
  _INVITEUSERSRESPONSE_USERINVITEISSUE._serialized_start=535
  _INVITEUSERSRESPONSE_USERINVITEISSUE._serialized_end=658
  _UPDATEUSERROLESREQUEST._serialized_start=661
  _UPDATEUSERROLESREQUEST._serialized_end=795
  _UPDATEUSERROLESRESPONSE._serialized_start=797
  _UPDATEUSERROLESRESPONSE._serialized_end=822
  _LISTORGANIZATIONMEMBERSREQUEST._serialized_start=824
  _LISTORGANIZATIONMEMBERSREQUEST._serialized_end=856
  _LISTORGANIZATIONMEMBERSRESPONSE._serialized_start=858
  _LISTORGANIZATIONMEMBERSRESPONSE._serialized_end=977
  _GETUSERREQUEST._serialized_start=979
  _GETUSERREQUEST._serialized_end=1026
  _GETUSERRESPONSE._serialized_start=1028
  _GETUSERRESPONSE._serialized_end=1100
  _ORGANIZATIONSSERVICE._serialized_start=1103
  _ORGANIZATIONSSERVICE._serialized_end=1659
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/cli/v1/cli.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n strmprivacy/api/cli/v1/cli.proto\x12\x16strmprivacy.api.cli.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17validate/validate.proto\"\xf5\x01\n\x11GetReleaseRequest\x12\xdf\x01\n\x07version\x18\x01 \x01(\tB\xc4\x01\xfa\x42\xc0\x01r\xbd\x01\x32\xb7\x01^v(0|[1-9]\\d*)\\.(0|[1-9]\\d*)\\.(0|[1-9]\\d*)(?:-((?:0|[1-9]\\d*|\\d*[a-zA-Z-][0-9a-zA-Z-]*)(?:\\.(?:0|[1-9]\\d*|\\d*[a-zA-Z-][0-9a-zA-Z-]*))*))?(?:\\+([0-9a-zA-Z-]+(?:\\.[0-9a-zA-Z-]+)*))?$/gm\xd0\x01\x01R\x07version\"W\n\x12GetReleaseResponse\x12\x41\n\x07release\x18\x01 \x01(\x0b\x32\".strmprivacy.api.cli.v1.CliReleaseB\x03\xe0\x41\x03R\x07release\"\xbd\x01\n\nCliRelease\x12\x1d\n\x07version\x18\x01 \x01(\tB\x03\xe0\x41\x03R\x07version\x12\x42\n\x0crelease_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03R\x0breleaseTime\x12\"\n\nsource_uri\x18\x03 \x01(\tB\x03\xe0\x41\x03R\tsourceUri\x12(\n\rrelease_notes\x18\x04 \x01(\tB\x03\xe0\x41\x03R\x0creleaseNotes2q\n\nCliService\x12\x63\n\nGetRelease\x12).strmprivacy.api.cli.v1.GetReleaseRequest\x1a*.strmprivacy.api.cli.v1.GetReleaseResponseBZ\n\x19io.strmprivacy.api.cli.v1P\x01Z;github.com/strmprivacy/api-definitions-go/v2/api/cli/v1;clib\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.cli.v1.cli_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031io.strmprivacy.api.cli.v1P\001Z;github.com/strmprivacy/api-definitions-go/v2/api/cli/v1;cli'
  _GETRELEASEREQUEST.fields_by_name['version']._options = None
  _GETRELEASEREQUEST.fields_by_name['version']._serialized_options = b'\372B\300\001r\275\0012\267\001^v(0|[1-9]\\d*)\\.(0|[1-9]\\d*)\\.(0|[1-9]\\d*)(?:-((?:0|[1-9]\\d*|\\d*[a-zA-Z-][0-9a-zA-Z-]*)(?:\\.(?:0|[1-9]\\d*|\\d*[a-zA-Z-][0-9a-zA-Z-]*))*))?(?:\\+([0-9a-zA-Z-]+(?:\\.[0-9a-zA-Z-]+)*))?$/gm\320\001\001'
  _GETRELEASERESPONSE.fields_by_name['release']._options = None
  _GETRELEASERESPONSE.fields_by_name['release']._serialized_options = b'\340A\003'
  _CLIRELEASE.fields_by_name['version']._options = None
  _CLIRELEASE.fields_by_name['version']._serialized_options = b'\340A\003'
  _CLIRELEASE.fields_by_name['release_time']._options = None
  _CLIRELEASE.fields_by_name['release_time']._serialized_options = b'\340A\003'
  _CLIRELEASE.fields_by_name['source_uri']._options = None
  _CLIRELEASE.fields_by_name['source_uri']._serialized_options = b'\340A\003'
  _CLIRELEASE.fields_by_name['release_notes']._options = None
  _CLIRELEASE.fields_by_name['release_notes']._serialized_options = b'\340A\003'
  _GETRELEASEREQUEST._serialized_start=152
  _GETRELEASEREQUEST._serialized_end=397
  _GETRELEASERESPONSE._serialized_start=399
  _GETRELEASERESPONSE._serialized_end=486
  _CLIRELEASE._serialized_start=489
  _CLIRELEASE._serialized_end=678
  _CLISERVICE._serialized_start=680
  _CLISERVICE._serialized_end=793
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/sinks/v1/sinks_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'strmprivacy/api/sinks/v1/sinks_v1.proto\x12\x18strmprivacy.api.sinks.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a-strmprivacy/api/entities/v1/entities_v1.proto\"\x84\x01\n\x10ListSinksRequest\x12\x1d\n\nbilling_id\x18\x01 \x01(\tR\tbillingId\x12\x1c\n\trecursive\x18\x02 \x01(\x08R\trecursive\x12/\n\x13include_credentials\x18\x03 \x01(\x08R\x12includeCredentials:\x02\x18\x01\"T\n\x11ListSinksResponse\x12;\n\x05sinks\x18\x01 \x03(\x0b\x32%.strmprivacy.api.entities.v1.SinkTreeR\x05sinks:\x02\x18\x01\"r\n\x11\x44\x65leteSinkRequest\x12;\n\x03ref\x18\x01 \x01(\x0b\x32$.strmprivacy.api.entities.v1.SinkRefB\x03\xe0\x41\x02R\x03ref\x12\x1c\n\trecursive\x18\x02 \x01(\x08R\trecursive:\x02\x18\x01\"\x18\n\x12\x44\x65leteSinkResponse:\x02\x18\x01\"\x84\x01\n\x11\x43reateSinkRequest\x12:\n\x04sink\x18\x01 \x01(\x0b\x32!.strmprivacy.api.entities.v1.SinkB\x03\xe0\x41\x02R\x04sink\x12/\n\x13include_credentials\x18\x02 \x01(\x08R\x12includeCredentials:\x02\x18\x01\"O\n\x12\x43reateSinkResponse\x12\x35\n\x04sink\x18\x01 \x01(\x0b\x32!.strmprivacy.api.entities.v1.SinkR\x04sink:\x02\x18\x01\"\xa0\x01\n\x0eGetSinkRequest\x12;\n\x03ref\x18\x01 \x01(\x0b\x32$.strmprivacy.api.entities.v1.SinkRefB\x03\xe0\x41\x02R\x03ref\x12\x1c\n\trecursive\x18\x02 \x01(\x08R\trecursive\x12/\n\x13include_credentials\x18\x03 \x01(\x08R\x12includeCredentials:\x02\x18\x01\"Y\n\x0fGetSinkResponse\x12\x42\n\tsink_tree\x18\x01 \x01(\x0b\x32%.strmprivacy.api.entities.v1.SinkTreeR\x08sinkTree:\x02\x18\x01\x32\xab\x03\n\x0cSinksService\x12\x64\n\tListSinks\x12*.strmprivacy.api.sinks.v1.ListSinksRequest\x1a+.strmprivacy.api.sinks.v1.ListSinksResponse\x12^\n\x07GetSink\x12(.strmprivacy.api.sinks.v1.GetSinkRequest\x1a).strmprivacy.api.sinks.v1.GetSinkResponse\x12g\n\nDeleteSink\x12+.strmprivacy.api.sinks.v1.DeleteSinkRequest\x1a,.strmprivacy.api.sinks.v1.DeleteSinkResponse\x12g\n\nCreateSink\x12+.strmprivacy.api.sinks.v1.CreateSinkRequest\x1a,.strmprivacy.api.sinks.v1.CreateSinkResponse\x1a\x03\x88\x02\x01\x42`\n\x1bio.strmprivacy.api.sinks.v1P\x01Z?github.com/strmprivacy/api-definitions-go/v2/api/sinks/v1;sinksb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.sinks.v1.sinks_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033io.strmprivacy.api.sinks.v1P\001Z?github.com/strmprivacy/api-definitions-go/v2/api/sinks/v1;sinks'
  _LISTSINKSREQUEST._options = None
  _LISTSINKSREQUEST._serialized_options = b'\030\001'
  _LISTSINKSRESPONSE._options = None
  _LISTSINKSRESPONSE._serialized_options = b'\030\001'
  _DELETESINKREQUEST.fields_by_name['ref']._options = None
  _DELETESINKREQUEST.fields_by_name['ref']._serialized_options = b'\340A\002'
  _DELETESINKREQUEST._options = None
  _DELETESINKREQUEST._serialized_options = b'\030\001'
  _DELETESINKRESPONSE._options = None
  _DELETESINKRESPONSE._serialized_options = b'\030\001'
  _CREATESINKREQUEST.fields_by_name['sink']._options = None
  _CREATESINKREQUEST.fields_by_name['sink']._serialized_options = b'\340A\002'
  _CREATESINKREQUEST._options = None
  _CREATESINKREQUEST._serialized_options = b'\030\001'
  _CREATESINKRESPONSE._options = None
  _CREATESINKRESPONSE._serialized_options = b'\030\001'
  _GETSINKREQUEST.fields_by_name['ref']._options = None
  _GETSINKREQUEST.fields_by_name['ref']._serialized_options = b'\340A\002'
  _GETSINKREQUEST._options = None
  _GETSINKREQUEST._serialized_options = b'\030\001'
  _GETSINKRESPONSE._options = None
  _GETSINKRESPONSE._serialized_options = b'\030\001'
  _SINKSSERVICE._options = None
  _SINKSSERVICE._serialized_options = b'\210\002\001'
  _LISTSINKSREQUEST._serialized_start=150
  _LISTSINKSREQUEST._serialized_end=282
  _LISTSINKSRESPONSE._serialized_start=284
  _LISTSINKSRESPONSE._serialized_end=368
  _DELETESINKREQUEST._serialized_start=370
  _DELETESINKREQUEST._serialized_end=484
  _DELETESINKRESPONSE._serialized_start=486
  _DELETESINKRESPONSE._serialized_end=510
  _CREATESINKREQUEST._serialized_start=513
  _CREATESINKREQUEST._serialized_end=645
  _CREATESINKRESPONSE._serialized_start=647
  _CREATESINKRESPONSE._serialized_end=726
  _GETSINKREQUEST._serialized_start=729
  _GETSINKREQUEST._serialized_end=889
  _GETSINKRESPONSE._serialized_start=891
  _GETSINKRESPONSE._serialized_end=980
  _SINKSSERVICE._serialized_start=983
  _SINKSSERVICE._serialized_end=1410
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/usage/v1/usage_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'strmprivacy/api/usage/v1/usage_v1.proto\x12\x18strmprivacy.api.usage.v1\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a-strmprivacy/api/entities/v1/entities_v1.proto\x1a\x17validate/validate.proto\"\x8b\x02\n\x1aGetStreamEventUsageRequest\x12\x38\n\x03ref\x18\x01 \x01(\x0b\x32&.strmprivacy.api.entities.v1.StreamRefR\x03ref\x12\x39\n\nstart_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tstartTime\x12\x35\n\x08\x65nd_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x07\x65ndTime\x12\x41\n\x08interval\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xfa\x42\x07\xaa\x01\x04\x32\x02\x08<R\x08interval\"\xa2\x01\n\x1bGetStreamEventUsageResponse\x12\x38\n\x03ref\x18\x01 \x01(\x0b\x32&.strmprivacy.api.entities.v1.StreamRefR\x03ref\x12I\n\x07windows\x18\x02 \x03(\x0b\x32/.strmprivacy.api.entities.v1.WindowedEventCountR\x07windows\"\x9c\x02\n\x16StoreUsageEventRequest\x12,\n\nbilling_id\x18\x01 \x01(\tB\r\x18\x01\xfa\x42\x08r\x06\x98\x01\x00\xd0\x01\x01R\tbillingId\x12\x37\n\x06stream\x18\x02 \x01(\tB\x1f\xfa\x42\x1cr\x1a\x10\x04\x18\x64\x32\x14^[\\pL\\pN\\pS\\pM\\pP]+$R\x06stream\x12(\n\x0b\x65vent_count\x18\x03 \x01(\x05\x42\x07\xfa\x42\x04\x1a\x02(\x00R\neventCount\x12H\n\x12\x65vent_arrival_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x10\x65ventArrivalTime\x12\'\n\nproject_id\x18\x05 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01R\tprojectId\"\x19\n\x17StoreUsageEventResponse2\x8b\x02\n\x0cUsageService\x12\x82\x01\n\x13GetStreamEventUsage\x12\x34.strmprivacy.api.usage.v1.GetStreamEventUsageRequest\x1a\x35.strmprivacy.api.usage.v1.GetStreamEventUsageResponse\x12v\n\x0fStoreUsageEvent\x12\x30.strmprivacy.api.usage.v1.StoreUsageEventRequest\x1a\x31.strmprivacy.api.usage.v1.StoreUsageEventResponseB`\n\x1bio.strmprivacy.api.usage.v1P\x01Z?github.com/strmprivacy/api-definitions-go/v2/api/usage/v1;usageb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.usage.v1.usage_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033io.strmprivacy.api.usage.v1P\001Z?github.com/strmprivacy/api-definitions-go/v2/api/usage/v1;usage'
  _GETSTREAMEVENTUSAGEREQUEST.fields_by_name['interval']._options = None
  _GETSTREAMEVENTUSAGEREQUEST.fields_by_name['interval']._serialized_options = b'\372B\007\252\001\0042\002\010<'
  _STOREUSAGEEVENTREQUEST.fields_by_name['billing_id']._options = None
  _STOREUSAGEEVENTREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001\372B\010r\006\230\001\000\320\001\001'
  _STOREUSAGEEVENTREQUEST.fields_by_name['stream']._options = None
  _STOREUSAGEEVENTREQUEST.fields_by_name['stream']._serialized_options = b'\372B\034r\032\020\004\030d2\024^[\\pL\\pN\\pS\\pM\\pP]+$'
  _STOREUSAGEEVENTREQUEST.fields_by_name['event_count']._options = None
  _STOREUSAGEEVENTREQUEST.fields_by_name['event_count']._serialized_options = b'\372B\004\032\002(\000'
  _STOREUSAGEEVENTREQUEST.fields_by_name['project_id']._options = None
  _STOREUSAGEEVENTREQUEST.fields_by_name['project_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _GETSTREAMEVENTUSAGEREQUEST._serialized_start=207
  _GETSTREAMEVENTUSAGEREQUEST._serialized_end=474
  _GETSTREAMEVENTUSAGERESPONSE._serialized_start=477
  _GETSTREAMEVENTUSAGERESPONSE._serialized_end=639
  _STOREUSAGEEVENTREQUEST._serialized_start=642
  _STOREUSAGEEVENTREQUEST._serialized_end=926
  _STOREUSAGEEVENTRESPONSE._serialized_start=928
  _STOREUSAGEEVENTRESPONSE._serialized_end=953
  _USAGESERVICE._serialized_start=956
  _USAGESERVICE._serialized_end=1223
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/batch_jobs/v1/batch_jobs_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1strmprivacy/api/batch_jobs/v1/batch_jobs_v1.proto\x12\x1dstrmprivacy.api.batch_jobs.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a-strmprivacy/api/entities/v1/entities_v1.proto\x1a\x17validate/validate.proto\"Z\n\x12GetBatchJobRequest\x12\x44\n\x03ref\x18\x01 \x01(\x0b\x32(.strmprivacy.api.entities.v1.BatchJobRefB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x03ref\"\xa2\x01\n\x13GetBatchJobResponse\x12\x46\n\tbatch_job\x18\x01 \x01(\x0b\x32%.strmprivacy.api.entities.v1.BatchJobB\x02\x18\x01R\x08\x62\x61tchJob\x12\x43\n\x03job\x18\x02 \x01(\x0b\x32,.strmprivacy.api.entities.v1.BatchJobWrapperB\x03\xe0\x41\x02R\x03job\"m\n\x14ListBatchJobsRequest\x12,\n\nbilling_id\x18\x01 \x01(\tB\r\x18\x01\xfa\x42\x08r\x06\x98\x01\x00\xd0\x01\x01R\tbillingId\x12\'\n\nproject_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01R\tprojectId\"\xa8\x01\n\x15ListBatchJobsResponse\x12H\n\nbatch_jobs\x18\x01 \x03(\x0b\x32%.strmprivacy.api.entities.v1.BatchJobB\x02\x18\x01R\tbatchJobs\x12\x45\n\x04jobs\x18\x02 \x03(\x0b\x32,.strmprivacy.api.entities.v1.BatchJobWrapperB\x03\xe0\x41\x02R\x04jobs\"\xa4\x01\n\x15\x43reateBatchJobRequest\x12\x46\n\tbatch_job\x18\x01 \x01(\x0b\x32%.strmprivacy.api.entities.v1.BatchJobB\x02\x18\x01R\x08\x62\x61tchJob\x12\x43\n\x03job\x18\x02 \x01(\x0b\x32,.strmprivacy.api.entities.v1.BatchJobWrapperB\x03\xe0\x41\x02R\x03job\"\xa8\x01\n\x16\x43reateBatchJobResponse\x12I\n\tbatch_job\x18\x01 \x01(\x0b\x32%.strmprivacy.api.entities.v1.BatchJobB\x05\x18\x01\xe0\x41\x02R\x08\x62\x61tchJob\x12\x43\n\x03job\x18\x02 \x01(\x0b\x32,.strmprivacy.api.entities.v1.BatchJobWrapperB\x03\xe0\x41\x02R\x03job\"]\n\x15\x44\x65leteBatchJobRequest\x12\x44\n\x03ref\x18\x01 \x01(\x0b\x32(.strmprivacy.api.entities.v1.BatchJobRefB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x03ref\"\x18\n\x16\x44\x65leteBatchJobResponse\"\xc0\x01\n\x1aUpdateBatchJobStateRequest\x12\x44\n\x03ref\x18\x01 \x01(\x0b\x32(.strmprivacy.api.entities.v1.BatchJobRefB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x03ref\x12\\\n\x0f\x62\x61tch_job_state\x18\x02 \x01(\x0b\x32*.strmprivacy.api.entities.v1.BatchJobStateB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\rbatchJobState\"\x1d\n\x1bUpdateBatchJobStateResponse2\x91\x05\n\x10\x42\x61tchJobsService\x12t\n\x0bGetBatchJob\x12\x31.strmprivacy.api.batch_jobs.v1.GetBatchJobRequest\x1a\x32.strmprivacy.api.batch_jobs.v1.GetBatchJobResponse\x12z\n\rListBatchJobs\x12\x33.strmprivacy.api.batch_jobs.v1.ListBatchJobsRequest\x1a\x34.strmprivacy.api.batch_jobs.v1.ListBatchJobsResponse\x12}\n\x0e\x43reateBatchJob\x12\x34.strmprivacy.api.batch_jobs.v1.CreateBatchJobRequest\x1a\x35.strmprivacy.api.batch_jobs.v1.CreateBatchJobResponse\x12}\n\x0e\x44\x65leteBatchJob\x12\x34.strmprivacy.api.batch_jobs.v1.DeleteBatchJobRequest\x1a\x35.strmprivacy.api.batch_jobs.v1.DeleteBatchJobResponse\x12\x8c\x01\n\x13UpdateBatchJobState\x12\x39.strmprivacy.api.batch_jobs.v1.UpdateBatchJobStateRequest\x1a:.strmprivacy.api.batch_jobs.v1.UpdateBatchJobStateResponseBo\n io.strmprivacy.api.batch_jobs.v1P\x01ZIgithub.com/strmprivacy/api-definitions-go/v2/api/batch_jobs/v1;batch_jobsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.batch_jobs.v1.batch_jobs_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n io.strmprivacy.api.batch_jobs.v1P\001ZIgithub.com/strmprivacy/api-definitions-go/v2/api/batch_jobs/v1;batch_jobs'
  _GETBATCHJOBREQUEST.fields_by_name['ref']._options = None
  _GETBATCHJOBREQUEST.fields_by_name['ref']._serialized_options = b'\372B\005\212\001\002\020\001'
  _GETBATCHJOBRESPONSE.fields_by_name['batch_job']._options = None
  _GETBATCHJOBRESPONSE.fields_by_name['batch_job']._serialized_options = b'\030\001'
  _GETBATCHJOBRESPONSE.fields_by_name['job']._options = None
  _GETBATCHJOBRESPONSE.fields_by_name['job']._serialized_options = b'\340A\002'
  _LISTBATCHJOBSREQUEST.fields_by_name['billing_id']._options = None
  _LISTBATCHJOBSREQUEST.fields_by_name['billing_id']._serialized_options = b'\030\001\372B\010r\006\230\001\000\320\001\001'
  _LISTBATCHJOBSREQUEST.fields_by_name['project_id']._options = None
  _LISTBATCHJOBSREQUEST.fields_by_name['project_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _LISTBATCHJOBSRESPONSE.fields_by_name['batch_jobs']._options = None
  _LISTBATCHJOBSRESPONSE.fields_by_name['batch_jobs']._serialized_options = b'\030\001'
  _LISTBATCHJOBSRESPONSE.fields_by_name['jobs']._options = None
  _LISTBATCHJOBSRESPONSE.fields_by_name['jobs']._serialized_options = b'\340A\002'
  _CREATEBATCHJOBREQUEST.fields_by_name['batch_job']._options = None
  _CREATEBATCHJOBREQUEST.fields_by_name['batch_job']._serialized_options = b'\030\001'
  _CREATEBATCHJOBREQUEST.fields_by_name['job']._options = None
  _CREATEBATCHJOBREQUEST.fields_by_name['job']._serialized_options = b'\340A\002'
  _CREATEBATCHJOBRESPONSE.fields_by_name['batch_job']._options = None
  _CREATEBATCHJOBRESPONSE.fields_by_name['batch_job']._serialized_options = b'\030\001\340A\002'
  _CREATEBATCHJOBRESPONSE.fields_by_name['job']._options = None
  _CREATEBATCHJOBRESPONSE.fields_by_name['job']._serialized_options = b'\340A\002'
  _DELETEBATCHJOBREQUEST.fields_by_name['ref']._options = None
  _DELETEBATCHJOBREQUEST.fields_by_name['ref']._serialized_options = b'\372B\005\212\001\002\020\001'
  _UPDATEBATCHJOBSTATEREQUEST.fields_by_name['ref']._options = None
  _UPDATEBATCHJOBSTATEREQUEST.fields_by_name['ref']._serialized_options = b'\372B\005\212\001\002\020\001'
  _UPDATEBATCHJOBSTATEREQUEST.fields_by_name['batch_job_state']._options = None
  _UPDATEBATCHJOBSTATEREQUEST.fields_by_name['batch_job_state']._serialized_options = b'\372B\005\212\001\002\020\001'
  _GETBATCHJOBREQUEST._serialized_start=189
  _GETBATCHJOBREQUEST._serialized_end=279
  _GETBATCHJOBRESPONSE._serialized_start=282
  _GETBATCHJOBRESPONSE._serialized_end=444
  _LISTBATCHJOBSREQUEST._serialized_start=446
  _LISTBATCHJOBSREQUEST._serialized_end=555
  _LISTBATCHJOBSRESPONSE._serialized_start=558
  _LISTBATCHJOBSRESPONSE._serialized_end=726
  _CREATEBATCHJOBREQUEST._serialized_start=729
  _CREATEBATCHJOBREQUEST._serialized_end=893
  _CREATEBATCHJOBRESPONSE._serialized_start=896
  _CREATEBATCHJOBRESPONSE._serialized_end=1064
  _DELETEBATCHJOBREQUEST._serialized_start=1066
  _DELETEBATCHJOBREQUEST._serialized_end=1159
  _DELETEBATCHJOBRESPONSE._serialized_start=1161
  _DELETEBATCHJOBRESPONSE._serialized_end=1185
  _UPDATEBATCHJOBSTATEREQUEST._serialized_start=1188
  _UPDATEBATCHJOBSTATEREQUEST._serialized_end=1380
  _UPDATEBATCHJOBSTATERESPONSE._serialized_start=1382
  _UPDATEBATCHJOBSTATERESPONSE._serialized_end=1411
  _BATCHJOBSSERVICE._serialized_start=1414
  _BATCHJOBSSERVICE._serialized_end=2071
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/credentials/v1/credentials_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from strmprivacy.api.entities.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_entities_dot_v1_dot_entities__v1__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3strmprivacy/api/credentials/v1/credentials_v1.proto\x12\x1estrmprivacy.api.credentials.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a-strmprivacy/api/entities/v1/entities_v1.proto\x1a\x17validate/validate.proto\"i\n\x16ListCredentialsRequest\x12O\n\nstream_ref\x18\x01 \x01(\x0b\x32&.strmprivacy.api.entities.v1.StreamRefB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\tstreamRef\"e\n\x17ListCredentialsResponse\x12J\n\x0b\x63redentials\x18\x01 \x03(\x0b\x32(.strmprivacy.api.entities.v1.CredentialsR\x0b\x63redentials\"@\n\x17\x44\x65leteCredentialRequest\x12%\n\tclient_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01R\x08\x63lientId\"\x1a\n\x18\x44\x65leteCredentialResponse\"=\n\x14GetCredentialRequest\x12%\n\tclient_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01R\x08\x63lientId\"a\n\x15GetCredentialResponse\x12H\n\ncredential\x18\x01 \x01(\x0b\x32(.strmprivacy.api.entities.v1.CredentialsR\ncredential\"j\n\x17\x43reateCredentialRequest\x12O\n\nstream_ref\x18\x01 \x01(\x0b\x32&.strmprivacy.api.entities.v1.StreamRefB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\tstreamRef\"k\n\x18\x43reateCredentialResponse\x12O\n\x0b\x63redentials\x18\x01 \x01(\x0b\x32(.strmprivacy.api.entities.v1.CredentialsB\x03\xe0\x41\x02R\x0b\x63redentials2\xa7\x04\n\x12\x43redentialsService\x12\x82\x01\n\x0fListCredentials\x12\x36.strmprivacy.api.credentials.v1.ListCredentialsRequest\x1a\x37.strmprivacy.api.credentials.v1.ListCredentialsResponse\x12|\n\rGetCredential\x12\x34.strmprivacy.api.credentials.v1.GetCredentialRequest\x1a\x35.strmprivacy.api.credentials.v1.GetCredentialResponse\x12\x85\x01\n\x10\x43reateCredential\x12\x37.strmprivacy.api.credentials.v1.CreateCredentialRequest\x1a\x38.strmprivacy.api.credentials.v1.CreateCredentialResponse\x12\x85\x01\n\x10\x44\x65leteCredential\x12\x37.strmprivacy.api.credentials.v1.DeleteCredentialRequest\x1a\x38.strmprivacy.api.credentials.v1.DeleteCredentialResponseBr\n!io.strmprivacy.api.credentials.v1P\x01ZKgithub.com/strmprivacy/api-definitions-go/v2/api/credentials/v1;credentialsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.credentials.v1.credentials_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!io.strmprivacy.api.credentials.v1P\001ZKgithub.com/strmprivacy/api-definitions-go/v2/api/credentials/v1;credentials'
  _LISTCREDENTIALSREQUEST.fields_by_name['stream_ref']._options = None
  _LISTCREDENTIALSREQUEST.fields_by_name['stream_ref']._serialized_options = b'\372B\005\212\001\002\020\001'
  _DELETECREDENTIALREQUEST.fields_by_name['client_id']._options = None
  _DELETECREDENTIALREQUEST.fields_by_name['client_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _GETCREDENTIALREQUEST.fields_by_name['client_id']._options = None
  _GETCREDENTIALREQUEST.fields_by_name['client_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _CREATECREDENTIALREQUEST.fields_by_name['stream_ref']._options = None
  _CREATECREDENTIALREQUEST.fields_by_name['stream_ref']._serialized_options = b'\372B\005\212\001\002\020\001'
  _CREATECREDENTIALRESPONSE.fields_by_name['credentials']._options = None
  _CREATECREDENTIALRESPONSE.fields_by_name['credentials']._serialized_options = b'\340A\002'
  _LISTCREDENTIALSREQUEST._serialized_start=192
  _LISTCREDENTIALSREQUEST._serialized_end=297
  _LISTCREDENTIALSRESPONSE._serialized_start=299
  _LISTCREDENTIALSRESPONSE._serialized_end=400
  _DELETECREDENTIALREQUEST._serialized_start=402
  _DELETECREDENTIALREQUEST._serialized_end=466
  _DELETECREDENTIALRESPONSE._serialized_start=468
  _DELETECREDENTIALRESPONSE._serialized_end=494
  _GETCREDENTIALREQUEST._serialized_start=496
  _GETCREDENTIALREQUEST._serialized_end=557
  _GETCREDENTIALRESPONSE._serialized_start=559
  _GETCREDENTIALRESPONSE._serialized_end=656
  _CREATECREDENTIALREQUEST._serialized_start=658
  _CREATECREDENTIALREQUEST._serialized_end=764
  _CREATECREDENTIALRESPONSE._serialized_start=766
  _CREATECREDENTIALRESPONSE._serialized_end=873
  _CREDENTIALSSERVICE._serialized_start=876
  _CREDENTIALSSERVICE._serialized_end=1427
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strmprivacy/api/customer_entity_versions/v1/customer_entity_versions_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from strmprivacy.api.installations.v1 import entities_v1_pb2 as strmprivacy_dot_api_dot_installations_dot_v1_dot_entities__v1__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nMstrmprivacy/api/customer_entity_versions/v1/customer_entity_versions_v1.proto\x12+strmprivacy.api.customer_entity_versions.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a\x32strmprivacy/api/installations/v1/entities_v1.proto\x1a\x17validate/validate.proto\"\x89\x01\n\x1cGetBatchExporterImageRequest\x12i\n\x11installation_type\x18\x01 \x01(\x0e\x32\x32.strmprivacy.api.installations.v1.InstallationTypeB\x08\xfa\x42\x05\x82\x01\x02 \x00R\x10installationType\"\x94\x01\n\x1dGetBatchExporterImageResponse\x12\x19\n\x05image\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x05image\x12\x36\n\x15\x61ws_marketplace_image\x18\x02 \x01(\tB\x02\x18\x01R\x13\x61wsMarketplaceImage\x12 \n\timage_tag\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x08imageTag\"\x1e\n\x1cGetKafkaExporterImageRequest\":\n\x1dGetKafkaExporterImageResponse\x12\x19\n\x05image\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x05image\"\x85\x01\n\x18GetDecrypterImageRequest\x12i\n\x11installation_type\x18\x01 \x01(\x0e\x32\x32.strmprivacy.api.installations.v1.InstallationTypeB\x08\xfa\x42\x05\x82\x01\x02 \x00R\x10installationType\"\x90\x01\n\x19GetDecrypterImageResponse\x12\x19\n\x05image\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x05image\x12\x36\n\x15\x61ws_marketplace_image\x18\x02 \x01(\tB\x02\x18\x01R\x13\x61wsMarketplaceImage\x12 \n\timage_tag\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x08imageTag\"\x8a\x01\n\x1dGetBatchJobRunnerImageRequest\x12i\n\x11installation_type\x18\x01 \x01(\x0e\x32\x32.strmprivacy.api.installations.v1.InstallationTypeB\x08\xfa\x42\x05\x82\x01\x02 \x00R\x10installationType\"\x95\x01\n\x1eGetBatchJobRunnerImageResponse\x12\x19\n\x05image\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x05image\x12\x36\n\x15\x61ws_marketplace_image\x18\x02 \x01(\tB\x02\x18\x01R\x13\x61wsMarketplaceImage\x12 \n\timage_tag\x18\x03 \x01(\tB\x03\xe0\x41\x02R\x08imageTag2\xda\x05\n\x1d\x43ustomerEntityVersionsService\x12\xae\x01\n\x15GetBatchExporterImage\x12I.strmprivacy.api.customer_entity_versions.v1.GetBatchExporterImageRequest\x1aJ.strmprivacy.api.customer_entity_versions.v1.GetBatchExporterImageResponse\x12\xae\x01\n\x15GetKafkaExporterImage\x12I.strmprivacy.api.customer_entity_versions.v1.GetKafkaExporterImageRequest\x1aJ.strmprivacy.api.customer_entity_versions.v1.GetKafkaExporterImageResponse\x12\xa2\x01\n\x11GetDecrypterImage\x12\x45.strmprivacy.api.customer_entity_versions.v1.GetDecrypterImageRequest\x1a\x46.strmprivacy.api.customer_entity_versions.v1.GetDecrypterImageResponse\x12\xb1\x01\n\x16GetBatchJobRunnerImage\x12J.strmprivacy.api.customer_entity_versions.v1.GetBatchJobRunnerImageRequest\x1aK.strmprivacy.api.customer_entity_versions.v1.GetBatchJobRunnerImageResponseB\x99\x01\n.io.strmprivacy.api.customer_entity_versions.v1P\x01Zegithub.com/strmprivacy/api-definitions-go/v2/api/customer_entity_versions/v1;customer_entity_versionsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'strmprivacy.api.customer_entity_versions.v1.customer_entity_versions_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n.io.strmprivacy.api.customer_entity_versions.v1P\001Zegithub.com/strmprivacy/api-definitions-go/v2/api/customer_entity_versions/v1;customer_entity_versions'
  _GETBATCHEXPORTERIMAGEREQUEST.fields_by_name['installation_type']._options = None
  _GETBATCHEXPORTERIMAGEREQUEST.fields_by_name['installation_type']._serialized_options = b'\372B\005\202\001\002 \000'
  _GETBATCHEXPORTERIMAGERESPONSE.fields_by_name['image']._options = None
  _GETBATCHEXPORTERIMAGERESPONSE.fields_by_name['image']._serialized_options = b'\340A\002'
  _GETBATCHEXPORTERIMAGERESPONSE.fields_by_name['aws_marketplace_image']._options = None
  _GETBATCHEXPORTERIMAGERESPONSE.fields_by_name['aws_marketplace_image']._serialized_options = b'\030\001'
  _GETBATCHEXPORTERIMAGERESPONSE.fields_by_name['image_tag']._options = None
  _GETBATCHEXPORTERIMAGERESPONSE.fields_by_name['image_tag']._serialized_options = b'\340A\002'
  _GETKAFKAEXPORTERIMAGERESPONSE.fields_by_name['image']._options = None
  _GETKAFKAEXPORTERIMAGERESPONSE.fields_by_name['image']._serialized_options = b'\340A\002'
  _GETDECRYPTERIMAGEREQUEST.fields_by_name['installation_type']._options = None
  _GETDECRYPTERIMAGEREQUEST.fields_by_name['installation_type']._serialized_options = b'\372B\005\202\001\002 \000'
  _GETDECRYPTERIMAGERESPONSE.fields_by_name['image']._options = None
  _GETDECRYPTERIMAGERESPONSE.fields_by_name['image']._serialized_options = b'\340A\002'
  _GETDECRYPTERIMAGERESPONSE.fields_by_name['aws_marketplace_image']._options = None
  _GETDECRYPTERIMAGERESPONSE.fields_by_name['aws_marketplace_image']._serialized_options = b'\030\001'
  _GETDECRYPTERIMAGERESPONSE.fields_by_name['image_tag']._options = None
  _GETDECRYPTERIMAGERESPONSE.fields_by_name['image_tag']._serialized_options = b'\340A\002'
  _GETBATCHJOBRUNNERIMAGEREQUEST.fields_by_name['installation_type']._options = None
  _GETBATCHJOBRUNNERIMAGEREQUEST.fields_by_name['installation_type']._serialized_options = b'\372B\005\202\001\002 \000'
  _GETBATCHJOBRUNNERIMAGERESPONSE.fields_by_name['image']._options = None
  _GETBATCHJOBRUNNERIMAGERESPONSE.fields_by_name['image']._serialized_options = b'\340A\002'
  _GETBATCHJOBRUNNERIMAGERESPONSE.fields_by_name['aws_marketplace_image']._options = None
  _GETBATCHJOBRUNNERIMAGERESPONSE.fields_by_name['aws_marketplace_image']._serialized_options = b'\030\001'
  _GETBATCHJOBRUNNERIMAGERESPONSE.fields_by_name['image_tag']._options = None
  _GETBATCHJOBRUNNERIMAGERESPONSE.fields_by_name['image_tag']._serialized_options = b'\340A\002'
  _GETBATCHEXPORTERIMAGEREQUEST._serialized_start=237
  _GETBATCHEXPORTERIMAGEREQUEST._serialized_end=374
  _GETBATCHEXPORTERIMAGERESPONSE._serialized_start=377
  _GETBATCHEXPORTERIMAGERESPONSE._serialized_end=525
  _GETKAFKAEXPORTERIMAGEREQUEST._serialized_start=527
  _GETKAFKAEXPORTERIMAGEREQUEST._serialized_end=557
  _GETKAFKAEXPORTERIMAGERESPONSE._serialized_start=559
  _GETKAFKAEXPORTERIMAGERESPONSE._serialized_end=617
  _GETDECRYPTERIMAGEREQUEST._serialized_start=620
  _GETDECRYPTERIMAGEREQUEST._serialized_end=753
  _GETDECRYPTERIMAGERESPONSE._serialized_start=756
  _GETDECRYPTERIMAGERESPONSE._serialized_end=900
  _GETBATCHJOBRUNNERIMAGEREQUEST._serialized_start=903
  _GETBATCHJOBRUNNERIMAGEREQUEST._serialized_end=1041
  _GETBATCHJOBRUNNERIMAGERESPONSE._serialized_start=1044
  _GETBATCHJOBRUNNERIMAGERESPONSE._serialized_end=1193
  _CUSTOMERENTITYVERSIONSSERVICE._serialized_start=1196
  _CUSTOMERENTITYVERSIONSSERVICE._serialized_end=1926
# @@protoc_insertion_point(module_scope)
